//**********************************************************************************************************
#ifndef ___Common___
#define ___Common___
//**********************************************************************************************************
#include <vector>
#include <map>
#include <stdio.h>
//**********************************************************************************************************
#ifndef WIN32
#	include <wx/app.h>
#	include <wx/bmpbuttn.h>
#	include <wx/buffer.h>
#	include <wx/button.h>
#	include <wx/checkbox.h>
#	include <wx/colour.h>
#	include <wx/combobox.h>
#	include <wx/defs.h>
#	include <wx/dir.h>
#	include <wx/dirdlg.h>
#	include <wx/filedlg.h>
#	include <wx/filename.h>
#	include <wx/frame.h>
#	include <wx/gauge.h>
#	include <wx/image.h>
#	include <wx/listbox.h>
#	include <wx/mediactrl.h>
#	include <wx/menu.h>
#	include <wx/msgdlg.h>
#	include <wx/notebook.h>
#	include <wx/panel.h>
#	include <wx/radiobox.h>
#	include <wx/slider.h>
#	include <wx/statbox.h>
#	include <wx/stattext.h>
#	include <wx/strconv.h>
#	include <wx/string.h>
#	include <wx/taskbar.h>
#	include <wx/textctrl.h>
#	include <wx/textfile.h>
#	include <wx/thread.h>
#	include <wx/timer.h>
#	include <wx/toolbar.h>
#	include <wx/wx.h>

#	include <stdio.h>
#	include <iostream>
#	include <fstream>
#	include <set>
#	include <map>
#	include <vector>

#	include <fileref.h>
#	include <tag.h>

#	include <General/STLSetMacros.h>
using namespace General::Utils;
#endif
//**********************************************************************************************************
class wxPanel;
class wxTextCtrl;
class wxStaticText;
class wxFileDialog;
class wxListBox;
class wxGauge;
class wxDirDialog;
class wxCheckBox;
class wxNotebook;
class wxStaticBox;
class wxButton;
class wxComboBox;
class wxRadioBox;
class wxTimer;
class wxToolBar;
class wxBitmapButton;
class wxSlider;
class wxTaskBarIcon;
class wxMediaCtrl;

class wxCommandEvent;
class wxNotebookEvent;
class wxListEvent;
class wxScrollEvent;
class wxTaskBarIconEvent;

typedef std::vector <wxBitmap>	wxBitmapArray;
typedef std::vector <wxColour>	wxColourArray;

namespace JokersPlayer
{
	class ImageButton;
	class FormEncode;
	class FormEncodingOptions;
	class FormMain;
	class FormPlaylist;
	class FormSearch;
	class FormTagEdit;
	class PlayerThread;
	class AudioPlayerThread;
	class Log;
	class TaskBarIcon;
	class JokerCtrl;
	class FormVideo;

	enum FileStatus
	{
		fsPlaying,
		fsLoaded,
		fsInitialised,
		fsNone
	};

	enum StereoMode
	{
		StandardStereo,
		JointStereo,
		DualChannel,
		Mono
	};

	struct Dimension
	{
		int Width;
		int Height;

		Dimension()
			:	Width( 0),
				Height( 0)
		{
		}

		Dimension( int p_w, int p_h)
			:	Width( p_w),
				Height( p_h)
		{
		}

		Dimension( const Dimension & p_dim)
			:	Width( p_dim.Width),
				Height( p_dim.Height)
		{
		}
	};

	enum PlayerStatus
	{
		STATUS_NONE		= 0,
		STATUS_INIT		= 1,
		STATUS_READY	= 2,
		STATUS_PLAY		= 3,
		STATUS_PAUSE	= 4,
		STATUS_STOP		= 5
	};

	struct EncodingOptions
	{
		bool m_vbr;
		int m_cbrBitRate;
		int m_vbrMinBitRate;
		int m_vbrMaxBitRate;
		int m_vbrQuality;
		bool m_vbrEnforceStrictlyMin;
		bool m_vbrEnableXingTag;

		int m_encodingQuality;
		int m_sampleRate;
		bool m_voiceEncodingMode;
		bool m_keepAllFrequancies;
		bool m_strictISOComplience;
		bool m_disableShortBlocks;
		bool m_modeFixed;
		StereoMode m_stereoMode;
		bool m_forcedMidSideStereo;

		EncodingOptions()
		{
			m_vbr = false;

			m_cbrBitRate = 160;

			m_vbrMinBitRate = 160;
			m_vbrMaxBitRate = 160;
			m_vbrQuality = 5;
			m_vbrEnforceStrictlyMin = false;
			m_vbrEnableXingTag = false;
			
			m_encodingQuality = 0;
			m_sampleRate = 22050;

			m_voiceEncodingMode = false;
			m_keepAllFrequancies = false;
			m_strictISOComplience = false;
			m_disableShortBlocks = false;
			m_modeFixed = false;
			m_stereoMode = StandardStereo;
			m_forcedMidSideStereo = false;
		}
	};

	struct SimpleDesign
	{
		wxString Name;
		wxColour m_1stColor;
		wxColourArray m_btnColours;
		wxColour m_3rdColor;
		wxColour m_1stTxtColor;
		wxColourArray m_btnFontColours;
		wxColour m_3rdTxtColor;

		SimpleDesign()
		{
			m_btnColours.push_back( wxColour( 192, 192, 192));
			m_btnColours.push_back( wxColour( 192, 192, 192));
			m_btnColours.push_back( wxColour( 192, 192, 192));
			m_btnColours.push_back( wxColour( 192, 192, 192));
			m_btnFontColours.push_back( wxColour( wxT( "black")));
			m_btnFontColours.push_back( wxColour( wxT( "black")));
			m_btnFontColours.push_back( wxColour( wxT( "black")));
			m_btnFontColours.push_back( wxColour( wxT( "black")));
		}
	};

	struct MP3Infos
	{
		wxString m_title;
		wxString m_track;
		wxString m_album;
		wxString m_year;
		wxString m_artist;
		wxString m_gender;

		void Init();
	};

	static const int g_buttonStyle = 0x00000001 | 0x00000100 | 0x00001000 | 0x00010000;

	bool IsMedia( const wxString & p_path);
	bool IsAudio( const wxString & p_path);
	bool IsVideo( const wxString & p_path);
	wxString GetStringFromStringTable( unsigned int uStringID);
	void MBToWC( const wxString & p_str, wxWCharBuffer & p_buffer);
}

typedef std::map <wxString, JokersPlayer::SimpleDesign *> DesignMap;
//**********************************************************************************************************
#endif
//**********************************************************************************************************
