//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "../Log.h"

#include "FormEncode.h"
#include "../other/EncoderThread.h"
#include "FormMain.h"
#include "FormEncodingOptions.h"
#include "../special/ImageButton.h"
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
FormEncode * g_formEncode;
extern FormEncodingOptions * g_formEncodingOptions;
//**********************************************************************************************************
enum FormEncodeIDs
{
	encodeOpenFile,
	encodeValidate,
	encodeCancel,
	encodeEditFileIn,
	encodeCancel3,
	encodeOptions,
	encodeStatus
};
//**********************************************************************************************************
BEGIN_EVENT_TABLE( FormEncode, wxFrame)
	EVT_BUTTON(		encodeOpenFile,		FormEncode::_onBtnOpenFileInClick)
	EVT_BUTTON(		encodeCancel,		FormEncode::_onBtnCancelClick)
	EVT_BUTTON(		encodeOptions,		FormEncode::_onOptionsBtnClick)
	EVT_BUTTON(		encodeValidate,		FormEncode::_onBtnValidateClick)
	EVT_BUTTON(		encodeCancel3,		FormEncode::_onBtnCancel3Click)
	EVT_TEXT(		encodeEditFileIn,	FormEncode::_onEFileInKeyUp)
END_EVENT_TABLE()
//**********************************************************************************************************

FormEncode :: FormEncode( wxWindow * p_parent)
	: 	wxFrame( p_parent, wxID_ANY, wxT( "Encoder"), wxDefaultPosition, wxSize( 435, 146), wxFRAME_TOOL_WINDOW | wxCAPTION | wxCLOSE_BOX | wxFRAME_FLOAT_ON_PARENT),
    	m_encodingOptions( new EncodingOptions)
{
	g_formEncode = this;
	m_panelStepOne = new wxPanel( this, wxID_ANY, wxPoint( 0, 0), GetClientSize());
	m_panelStepThree = new wxPanel( this, wxID_ANY, wxPoint( 0, 0), GetClientSize());
	
#ifndef __GNUG_
	m_btnOpenFileIn = new ImageButton( m_panelStepOne, encodeOpenFile, wxT( "Parcourir"), wxPoint( 278, 32), wxSize( 70, 25), g_buttonStyle);
	m_btnCancel = new ImageButton( m_panelStepOne, encodeCancel, wxT( "Annuler"), wxPoint( 23, 81), wxSize( 90, 32), g_buttonStyle);
	m_optionsBtn = new ImageButton( m_panelStepOne, encodeOptions, wxT( "Options"), wxPoint( 168, 81), wxSize( 90, 32), g_buttonStyle);
	m_btnValidate = new ImageButton( m_panelStepOne, encodeValidate, wxT( "Valider"), wxPoint( 314, 81), wxSize( 90, 32), g_buttonStyle);
	m_btnCancel3 = new ImageButton( m_panelStepThree, encodeCancel3, wxT( "Terminer"), wxPoint( 168, 81), wxSize( 90, 32), g_buttonStyle);
#else
	m_btnOpenFileIn = new wxButton( m_panelStepOne, encodeOpenFile, wxT( "Parcourir"), wxPoint( 278, 32), wxSize( 70, 25), g_buttonStyle);
	m_btnCancel = new wxButton( m_panelStepOne, encodeCancel, wxT( "Annuler"), wxPoint( 23, 81), wxSize( 90, 32), g_buttonStyle);
	m_optionsBtn = new wxButton( m_panelStepOne, encodeOptions, wxT( "Options"), wxPoint( 168, 81), wxSize( 90, 32), g_buttonStyle);
	m_btnValidate = new wxButton( m_panelStepOne, encodeValidate, wxT( "Valider"), wxPoint( 314, 81), wxSize( 90, 32), g_buttonStyle);
	m_btnCancel3 = new wxButton( m_panelStepThree, encodeCancel3, wxT( "Terminer"), wxPoint( 168, 81), wxSize( 90, 32), g_buttonStyle);
#endif
	m_editFileIn = new wxTextCtrl( m_panelStepOne, encodeEditFileIn, wxEmptyString, wxPoint( 68, 32), wxSize( 190, 21));
	m_panelStepOne->Show();

	m_ststatus = new wxStaticText( m_panelStepThree, wxID_ANY, wxT( "Statut"), wxPoint( 192, 16));
	m_status = new wxGauge( m_panelStepThree, encodeStatus, 100, wxPoint( 135, 40), wxSize( 150, 16), wxGA_HORIZONTAL);
	m_panelStepThree->Hide();

	g_formEncodingOptions = new FormEncodingOptions( this);
	g_formEncodingOptions->Hide();
}

//**********************************************************************************************************

void FormEncode :: SetSimpleDesign( SimpleDesign * p_sd)
{
	if (p_sd == NULL)
	{        
		Log::LogMessage( "ERROR : FormEncode :: SetSimpleDesign - Design Null");
		return;
	}
	m_simpleDesign = p_sd;

	SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_panelStepOne->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_panelStepThree->SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_editFileIn->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_editFileIn->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);

	m_btnOpenFileIn->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnValidate->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_optionsBtn->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnCancel->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnCancel3->SetBackgroundColour( m_simpleDesign->m_1stColor);

#ifdef WIN32
	m_btnOpenFileIn->SetColours( m_simpleDesign->m_btnColours);
	m_btnOpenFileIn->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnValidate->SetColours( m_simpleDesign->m_btnColours);
	m_btnValidate->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_optionsBtn->SetColours( m_simpleDesign->m_btnColours);
	m_optionsBtn->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnCancel->SetColours( m_simpleDesign->m_btnColours);
	m_btnCancel->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnCancel3->SetColours( m_simpleDesign->m_btnColours);
	m_btnCancel3->SetFontColours( m_simpleDesign->m_btnFontColours);
#else
	m_btnOpenFileIn->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnValidate->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_optionsBtn->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnCancel->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnCancel3->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
#endif
	
	m_status->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_status->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	
	g_formEncodingOptions->SetSimpleDesign(m_simpleDesign);
	
	Refresh();
}

//**********************************************************************************************************

void FormEncode :: SetEncodingOptions( const EncodingOptions & p_options)
{
	m_encodingOptions->m_vbr = p_options.m_vbr;
	m_encodingOptions->m_cbrBitRate = p_options.m_cbrBitRate;
	m_encodingOptions->m_disableShortBlocks = p_options.m_disableShortBlocks;
	m_encodingOptions->m_encodingQuality = p_options.m_encodingQuality;
	m_encodingOptions->m_forcedMidSideStereo = p_options.m_forcedMidSideStereo;
	m_encodingOptions->m_keepAllFrequancies = p_options.m_keepAllFrequancies;
	m_encodingOptions->m_modeFixed = p_options.m_modeFixed;
	m_encodingOptions->m_sampleRate = p_options.m_sampleRate;
	m_encodingOptions->m_stereoMode = p_options.m_stereoMode;
	m_encodingOptions->m_strictISOComplience = p_options.m_strictISOComplience;
	m_encodingOptions->m_vbrEnableXingTag = p_options.m_vbrEnableXingTag;
	m_encodingOptions->m_vbrEnforceStrictlyMin = p_options.m_vbrEnforceStrictlyMin;
	m_encodingOptions->m_vbrMaxBitRate = p_options.m_vbrMaxBitRate;
	m_encodingOptions->m_vbrMinBitRate = p_options.m_vbrMinBitRate;
	m_encodingOptions->m_vbrQuality = p_options.m_vbrQuality;
	m_encodingOptions->m_voiceEncodingMode = p_options.m_voiceEncodingMode;
}

//**********************************************************************************************************

void FormEncode :: _onBtnOpenFileInClick( wxCommandEvent & p_event)
{
	wxFileDialog * l_openEncodeFile = new wxFileDialog( this, wxT( "Choisissez un fichier"), wxEmptyString, 
														wxEmptyString, wxT( "*.wav"));
	if (l_openEncodeFile->ShowModal() == wxID_OK)
	{
		m_editFileIn->SetValue( l_openEncodeFile->GetPath());
		m_inFilePath = l_openEncodeFile->GetPath();
	    size_t l_pos = m_inFilePath.find_last_of( wxT( "."));
		m_outFilePath = m_inFilePath.SubString(0,l_pos - 1) + wxT( ".mp3");
	}
	l_openEncodeFile->Close();
}

//**********************************************************************************************************

void FormEncode :: _onEFileInKeyUp( wxCommandEvent & p_event)
{
	m_inFilePath = m_editFileIn->GetValue();
}

//**********************************************************************************************************

void FormEncode :: _onBtnCancelClick( wxCommandEvent & p_event)
{
	Hide();
}            

//**********************************************************************************************************

void FormEncode :: _onOptionsBtnClick( wxCommandEvent & p_event)
{
	g_formEncodingOptions->Show();
}

//**********************************************************************************************************

void FormEncode :: _onBtnValidateClick( wxCommandEvent & p_event)
{    
	if (m_inFilePath.IsEmpty() || m_outFilePath.IsEmpty())
	{
		Log::LogMessage( "ERROR : FormEncode :: BtnValidateClick - Void file names");
		return;
	}

	m_panelStepOne->Hide();
	m_panelStepThree->Show();
	EncoderThread * l_encoderThread = new EncoderThread( m_encodingOptions, m_inFilePath, m_outFilePath);
	l_encoderThread->Create();
	l_encoderThread->Run();
}

//**********************************************************************************************************

void FormEncode :: _onBtnCancel3Click( wxCommandEvent & p_event)
{
	Hide();
	m_panelStepOne->Show();
	m_panelStepThree->Hide();
}

//**********************************************************************************************************
