//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "../Log.h"

#include "FormEncodingOptions.h"
#include "FormEncode.h"
#include "FormMain.h"
#include "../special/ImageButton.h"
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
FormEncodingOptions * g_formEncodingOptions;
extern FormEncode * g_formEncode;
//**********************************************************************************************************
enum FormEncodingOptionsIDs
{
	optionsTabs,
	optionsVBRMin,
	optionsVBRMax,
	optionsMF,
	optionsVBRQuality,
//	optionsVBRSampleRate,
	optionsSampleRate,
	optionsCBRBitRate,
	optionsValidate,
	optionsCancel,
	optionsEncodingType,
	optionsModeSelection,
	optionsSEVBRMBR,
	optionsVEM,
	optionsKAF,
	optionsEXVBRT,
	optionsDSB,
	optionsSISOC,
	optionsEncodingQuality
};
//**********************************************************************************************************
BEGIN_EVENT_TABLE( FormEncodingOptions, wxFrame)
	EVT_BUTTON(						optionsCancel,			FormEncodingOptions::_onBtnCancelClick)
	EVT_BUTTON(						optionsValidate,		FormEncodingOptions::_onBtnValidateClick)
	EVT_CHECKBOX(					optionsSEVBRMBR,		FormEncodingOptions::_onSEVBRMBRClick)
	EVT_CHECKBOX(					optionsVEM,				FormEncodingOptions::_onVEMClick)
	EVT_CHECKBOX(					optionsKAF,				FormEncodingOptions::_onKAFClick)
	EVT_CHECKBOX(					optionsSISOC,			FormEncodingOptions::_onSISOCClick)
	EVT_CHECKBOX(					optionsDSB,				FormEncodingOptions::_onDSBClick)
	EVT_CHECKBOX(					optionsEXVBRT,			FormEncodingOptions::_onEXVBRTClick)
	EVT_CHECKBOX(					optionsMF,				FormEncodingOptions::_onMFClick)
	EVT_RADIOBOX(					optionsModeSelection,	FormEncodingOptions::_onModeSelectionClick)
	EVT_RADIOBOX(					optionsEncodingType,	FormEncodingOptions::_onEncodingTypeClick)
	EVT_COMBOBOX(					optionsCBRBitRate,		FormEncodingOptions::_onCBRBitRateChange)
	EVT_COMBOBOX(					optionsVBRMin,			FormEncodingOptions::_onVBRMinChange)
	EVT_COMBOBOX(					optionsVBRMax,			FormEncodingOptions::_onVBRMaxChange)
	EVT_COMBOBOX(					optionsVBRQuality,		FormEncodingOptions::_onVBRQualityChange)
	EVT_COMBOBOX(					optionsSampleRate,		FormEncodingOptions::_onSampleRateChange)
	EVT_COMMAND_SCROLL_THUMBTRACK(	optionsEncodingQuality,	FormEncodingOptions::_onEncodingQualityChange)
END_EVENT_TABLE()
//**********************************************************************************************************

FormEncodingOptions :: FormEncodingOptions( wxWindow * p_parent)
	: wxFrame( p_parent, wxID_ANY, wxT( "Options d'encodage"), wxPoint( 0, 0), wxSize( 434, 258), wxFRAME_TOOL_WINDOW | wxCAPTION | wxCLOSE_BOX | wxFRAME_FLOAT_ON_PARENT)
{
	g_formEncodingOptions = this;
	wxArrayString l_choices;
	
	m_tabSet = new wxNotebook( this, optionsTabs, wxPoint( 0, 0), wxSize( 426, 184), wxNB_FLAT);
	m_generalTab = new wxPanel( m_tabSet, wxID_ANY, wxPoint( 0, 0), wxSize( 426, 184));
	m_tabSet->AddPage( m_generalTab, wxT( "GenerawxT( "));
#ifdef WIN32
	m_CBRGB = new wxStaticBox( m_generalTab, wxID_ANY, wxT( "CBR Options"), wxPoint( 0, 35), wxSize( 201, 57));
	m_label1 = new wxStaticText( m_CBRGB, wxID_ANY, wxT( "Kbit/s"), wxPoint( 11, 28));
#else
	m_label1 = new wxStaticText( m_generalTab, wxID_ANY, wxT( "Kbit/s"), wxPoint( 11, 63));
#endif
	l_choices.push_back( wxT( "8 kbps"));
	l_choices.push_back( wxT( "16 kbps"));
	l_choices.push_back( wxT( "24 kbps"));
	l_choices.push_back( wxT( "32 kbps"));
	l_choices.push_back( wxT( "40 kbps"));
	l_choices.push_back( wxT( "48 kbps"));
	l_choices.push_back( wxT( "56 kbps"));
	l_choices.push_back( wxT( "64 kbps"));
	l_choices.push_back( wxT( "80 kbps"));
	l_choices.push_back( wxT( "96 kbps"));
	l_choices.push_back( wxT( "112 kbps"));
	l_choices.push_back( wxT( "128 kbps"));
	l_choices.push_back( wxT( "144 kbps"));
	l_choices.push_back( wxT( "160 kbps"));
	l_choices.push_back( wxT( "192 kbps"));
	l_choices.push_back( wxT( "256 kbps"));
	l_choices.push_back( wxT( "320 kbps"));
#ifdef WIN32
	m_CBRBitRate = new wxComboBox( m_CBRGB, optionsCBRBitRate, wxT( "160 kbps"), wxPoint( 44, 24), wxSize( 145, 21), l_choices, wxCB_READONLY);
#else
	m_CBRBitRate = new wxComboBox( m_generalTab, optionsCBRBitRate, wxT( "160 kbps"), wxPoint( 44, 59), wxSize( 145, 21), l_choices, wxCB_READONLY);
#endif
	l_choices.clear();
	l_choices.push_back( wxT( "48 kHz"));
	l_choices.push_back( wxT( "44.1 kHz"));
	l_choices.push_back( wxT( "32 kHz"));
	l_choices.push_back( wxT( "24 kHz"));
	l_choices.push_back( wxT( "22.05 kHz"));
	l_choices.push_back( wxT( "16 kHz"));
	m_sampleRate = new wxComboBox( m_generalTab, optionsSampleRate, wxT( "22.05 kHz"), wxPoint( 108, 136), wxSize( 102, 21), l_choices, wxCB_READONLY);
	m_label5 = new wxStaticText( m_generalTab, wxID_ANY, wxT( "Encoding Quality"), wxPoint( 11, 98));
	m_label6 = new wxStaticText( m_generalTab, wxID_ANY, wxT( "High"), wxPoint( 141, 98));
	l_choices.clear();
	l_choices.push_back( wxT( "Constant Bit Rate"));
	l_choices.push_back( wxT( "Variable Bit Rate"));
	m_encodingType = new wxRadioBox( m_generalTab, optionsEncodingType, wxT( "Encoding Type"), wxPoint( 0, 0), wxSize( 425, 36), l_choices);
	m_targetSampleRate = new wxStaticText( m_generalTab, wxID_ANY, wxT( "Target Sample Rate"), wxPoint( 7, 140));
	m_encodingQuality = new wxSlider( m_generalTab, optionsEncodingQuality, 0, 0, 10, wxPoint( 0, 116), wxSize( 201, 14));
#ifdef WIN32
	m_VBRGB = new wxStaticBox( m_generalTab, wxID_ANY, wxT( "VBR Options"), wxPoint( 216, 35), wxSize( 210, 98));
	m_label2 = new wxStaticText( m_VBRGB, wxID_ANY, wxT( "Min."), wxPoint( 10, 19));
	m_label3 = new wxStaticText( m_VBRGB, wxID_ANY, wxT( "Max."), wxPoint( 10, 46));
	m_label4 = new wxStaticText( m_VBRGB, wxID_ANY, wxT( "VBR Quality"), wxPoint( 10, 74));
#else
	m_label2 = new wxStaticText( m_generalTab, wxID_ANY, wxT( "Min."), wxPoint( 226, 54));
	m_label3 = new wxStaticText( m_generalTab, wxID_ANY, wxT( "Max."), wxPoint( 226, 81));
	m_label4 = new wxStaticText( m_generalTab, wxID_ANY, wxT( "VBR Quality"), wxPoint( 226, 109));
#endif
	l_choices.clear();
	l_choices.push_back( wxT( "8 kbps"));
	l_choices.push_back( wxT( "16 kbps"));
	l_choices.push_back( wxT( "24 kbps"));
	l_choices.push_back( wxT( "32 kbps"));
	l_choices.push_back( wxT( "40 kbps"));
	l_choices.push_back( wxT( "48 kbps"));
	l_choices.push_back( wxT( "56 kbps"));
	l_choices.push_back( wxT( "64 kbps"));
	l_choices.push_back( wxT( "80 kbps"));
	l_choices.push_back( wxT( "96 kbps"));
	l_choices.push_back( wxT( "112 kbps"));
	l_choices.push_back( wxT( "128 kbps"));
	l_choices.push_back( wxT( "144 kbps"));
	l_choices.push_back( wxT( "160 kbps"));
	l_choices.push_back( wxT( "192 kbps"));
	l_choices.push_back( wxT( "256 kbps"));
	l_choices.push_back( wxT( "320 kbps"));
#ifdef WIN32
	m_VBRMin = new wxComboBox( m_VBRGB, optionsVBRMin, wxT( "160 kbps"), wxPoint( 52, 16), wxSize( 145, 21), l_choices, wxCB_READONLY);
	m_VBRMax = new wxComboBox( m_VBRGB, optionsVBRMax, wxT( "160 kbps"), wxPoint( 52, 43), wxSize( 145, 21), l_choices, wxCB_READONLY);
#else
	m_VBRMin = new wxComboBox( m_generalTab, optionsVBRMin, wxT( "160 kbps"), wxPoint( 268, 51), wxSize( 145, 21), l_choices, wxCB_READONLY);
	m_VBRMax = new wxComboBox( m_generalTab, optionsVBRMax, wxT( "160 kbps"), wxPoint( 268, 78), wxSize( 145, 21), l_choices, wxCB_READONLY);
#endif
	l_choices.clear();
	l_choices.push_back( wxT( "0 - ~1:4"));
	l_choices.push_back( wxT( "1 - ~1:5"));
	l_choices.push_back( wxT( "2 - ~1:6"));
	l_choices.push_back( wxT( "3 - ~1:7"));
	l_choices.push_back( wxT( "4 - ~1:8"));
	l_choices.push_back( wxT( "5 - ~1:9"));
	l_choices.push_back( wxT( "6 - ~1:10"));
	l_choices.push_back( wxT( "7 - ~1:11"));
	l_choices.push_back( wxT( "8 - ~1:12"));
	l_choices.push_back( wxT( "9 - ~1:14"));
#ifdef WIN32
	m_VBRQuality = new wxComboBox( m_VBRGB, optionsVBRQuality, wxT( "5 - ~1:9"), wxPoint( 73, 70), wxSize( 124, 21), l_choices, wxCB_READONLY);
	m_VBRGB->Enable( false);
#else
	m_VBRQuality = new wxComboBox( m_generalTab, optionsVBRQuality, wxT( "5 - ~1:9"), wxPoint( 289, 105), wxSize( 124, 21), l_choices, wxCB_READONLY);
#endif

	m_advancedTab = new wxPanel( m_tabSet, wxID_ANY, wxPoint( 0, 0), wxSize( 426, 184));
	m_tabSet->AddPage( m_advancedTab, wxT( "Avancé"));
	m_SEVBRMBR = new wxCheckBox( m_advancedTab, optionsSEVBRMBR, wxT( "Strictly Enforce VBR min bit rate"), wxPoint( 7, 12));
	m_VEM = new wxCheckBox( m_advancedTab, optionsVEM, wxT( "Voice Encoding Mode"), wxPoint( 7, 30));
	m_KAF = new wxCheckBox( m_advancedTab, optionsKAF, wxT( "Keep All Frequencies"), wxPoint( 7, 48));
	m_SISOC = new wxCheckBox( m_advancedTab, optionsSISOC, wxT( "Strict ISO Complience"), wxPoint( 7, 66));
	m_DSB = new wxCheckBox( m_advancedTab, optionsDSB, wxT( "Disable Short Blocks"), wxPoint( 7, 84));
	m_EXVBRT = new wxCheckBox( m_advancedTab, optionsEXVBRT, wxT( "Enable Xing VBR Tag"), wxPoint( 7, 102));
	m_MF = new wxCheckBox( m_advancedTab, optionsMF, wxT( "Mode Fixed"), wxPoint( 7, 120));
	l_choices.clear();
	l_choices.push_back( wxT( "Standard Stereo"));
	l_choices.push_back( wxT( "Joint Stereo"));
	l_choices.push_back( wxT( "Dual Channel"));
	l_choices.push_back( wxT( "Mono"));
	m_modeSelection = new wxRadioBox( m_advancedTab, optionsModeSelection, wxT( "Mode Selection"), wxPoint( 256, 17), wxSize( 122, 105), l_choices, 4, wxRA_SPECIFY_ROWS);

#ifdef WIN32
	m_btnValidate = new ImageButton( this, optionsValidate, wxT( "Valider"), wxPoint( 282, 191), wxSize( 90, 32), g_buttonStyle);
	m_btnCancel = new ImageButton( this, optionsCancel, wxT( "Annuler"), wxPoint( 76, 191), wxSize( 90, 32), g_buttonStyle);
#else
	m_btnValidate = new wxButton( this, optionsValidate, wxT( "Valider"), wxPoint( 282, 191), wxSize( 90, 32), g_buttonStyle);
	m_btnCancel = new wxButton( this, optionsCancel, wxT( "Annuler"), wxPoint( 76, 191), wxSize( 90, 32), g_buttonStyle);
#endif
}  

//**********************************************************************************************************

void FormEncodingOptions :: SetSimpleDesign( SimpleDesign * p_sd)
{
	if (p_sd == NULL)
	{
		Log::LogMessage( "ERROR : FormEncodingOptions :: SetSimpleDesign - Design NulwxT( ");
		return;
	}

	m_simpleDesign = p_sd;

	SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_generalTab->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_advancedTab->SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_tabSet->SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_VBRMin->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_VBRMin->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	m_VBRMax->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_VBRMax->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	m_VBRQuality->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_VBRQuality->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	m_CBRBitRate->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_CBRBitRate->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	m_sampleRate->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_sampleRate->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);

	m_btnValidate->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnCancel->SetBackgroundColour( m_simpleDesign->m_1stColor);

#ifdef WIN32
	m_btnValidate->SetColours( m_simpleDesign->m_btnColours);
	m_btnValidate->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnCancel->SetColours( m_simpleDesign->m_btnColours);
	m_btnCancel->SetFontColours( m_simpleDesign->m_btnFontColours);
#endif

	m_SEVBRMBR->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_SEVBRMBR->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	m_VEM->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_VEM->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	m_KAF->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_KAF->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	m_MF->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_MF->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	m_EXVBRT->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_EXVBRT->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	m_DSB->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_DSB->SetForegroundColour( m_simpleDesign->m_1stTxtColor);
	m_SISOC->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_SISOC->SetForegroundColour( m_simpleDesign->m_1stTxtColor);

	Refresh();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onBtnValidateClick( wxCommandEvent & p_event)
{
	g_formEncode->SetEncodingOptions( m_encodingOptions);
	Hide();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onBtnCancelClick( wxCommandEvent & p_event)
{
	Hide();	
}

//**********************************************************************************************************

void FormEncodingOptions :: _onSEVBRMBRClick( wxCommandEvent & p_event)
{
	m_encodingOptions.m_vbrEnforceStrictlyMin = m_SEVBRMBR->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onVEMClick( wxCommandEvent & p_event)
{
	m_encodingOptions.m_voiceEncodingMode = m_VEM->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onKAFClick( wxCommandEvent & p_event)
{
	m_encodingOptions.m_keepAllFrequancies = m_KAF->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onSISOCClick( wxCommandEvent & p_event)
{   
	m_encodingOptions.m_strictISOComplience = m_SISOC->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onDSBClick( wxCommandEvent & p_event)
{
	m_encodingOptions.m_disableShortBlocks = m_DSB->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onEXVBRTClick( wxCommandEvent & p_event)
{
	m_encodingOptions.m_vbrEnableXingTag = m_EXVBRT->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onMFClick( wxCommandEvent & p_event)
{
	m_encodingOptions.m_modeFixed = m_MF->IsChecked();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onModeSelectionClick( wxCommandEvent & p_event)
{
	int l_index = m_modeSelection->GetSelection();
	if (l_index == 0)
	{
		m_encodingOptions.m_stereoMode = StandardStereo;
	}
	else if (l_index == 1)
	{
		m_encodingOptions.m_stereoMode = JointStereo;
	}
	else if (l_index == 2)
	{
		m_encodingOptions.m_stereoMode = DualChannel;
	}
	else
	{
		m_encodingOptions.m_stereoMode = Mono;
	}
}

//**********************************************************************************************************

void FormEncodingOptions :: _onEncodingTypeClick( wxCommandEvent & p_event)
{
	int l_index = m_encodingType->GetSelection();
	if (l_index == 0)
	{
		m_encodingOptions.m_vbr = false;
		m_VBRGB->Enable( false);
		m_CBRGB->Enable( true);
	}
	else
	{                  
		m_encodingOptions.m_vbr = true;
		m_VBRGB->Enable( true);
		m_CBRGB->Enable( false);
	}
}

//**********************************************************************************************************

void FormEncodingOptions :: _onCBRBitRateChange( wxCommandEvent & p_event)
{
	int l_index = m_CBRBitRate->GetCurrentSelection();
	if (l_index == 0)
	{
		m_encodingOptions.m_cbrBitRate = 8;
	}
	else if (l_index == 1)
	{
		m_encodingOptions.m_cbrBitRate = 16;
	}
	else if (l_index == 2)
	{
		m_encodingOptions.m_cbrBitRate = 24;
	}
	else if (l_index == 3)
	{
		m_encodingOptions.m_cbrBitRate = 32;
	}
	else if (l_index == 4)
	{
		m_encodingOptions.m_cbrBitRate = 40;
	}
	else if (l_index == 5)
	{
		m_encodingOptions.m_cbrBitRate = 48;
	}
	else if (l_index == 6)
	{
		m_encodingOptions.m_cbrBitRate = 56;
	}
	else if (l_index == 7)
	{
		m_encodingOptions.m_cbrBitRate = 64;
	}
	else if (l_index == 8)
	{
		m_encodingOptions.m_cbrBitRate = 80;
	}
	else if (l_index == 9)
	{
		m_encodingOptions.m_cbrBitRate = 96;
	}
	else if (l_index == 10)
	{
		m_encodingOptions.m_cbrBitRate = 112;
	}
	else if (l_index == 11)
	{
		m_encodingOptions.m_cbrBitRate = 128;
	}
	else if (l_index == 12)
	{
		m_encodingOptions.m_cbrBitRate = 144;
	}
	else if (l_index == 13)
	{
		m_encodingOptions.m_cbrBitRate = 160;
	}
	else if (l_index == 14)
	{
		m_encodingOptions.m_cbrBitRate = 192;
	}
	else if (l_index == 15)
	{
		m_encodingOptions.m_cbrBitRate = 256;
	}
	else if (l_index == 16)
	{
		m_encodingOptions.m_cbrBitRate = 320;
	}
}

//**********************************************************************************************************

void FormEncodingOptions :: _onVBRMinChange( wxCommandEvent & p_event)
{
	int l_index = m_VBRMin->GetCurrentSelection();
	if (l_index == 0)
	{
		m_encodingOptions.m_vbrMinBitRate = 8;
	}
	else if (l_index == 1)
	{
		m_encodingOptions.m_vbrMinBitRate = 16;
	}
	else if (l_index == 2)
	{
		m_encodingOptions.m_vbrMinBitRate = 24;
	}
	else if (l_index == 3)
	{
		m_encodingOptions.m_vbrMinBitRate = 32;
	}
	else if (l_index == 4)
	{
		m_encodingOptions.m_vbrMinBitRate = 40;
	}
	else if (l_index == 5)
	{
		m_encodingOptions.m_vbrMinBitRate = 48;
	}
	else if (l_index == 6)
	{
		m_encodingOptions.m_vbrMinBitRate = 56;
	}
	else if (l_index == 7)
	{
		m_encodingOptions.m_vbrMinBitRate = 64;
	}
	else if (l_index == 8)
	{
		m_encodingOptions.m_vbrMinBitRate = 80;
	}
	else if (l_index == 9)
	{
		m_encodingOptions.m_vbrMinBitRate = 96;
	}
	else if (l_index == 10)
	{
		m_encodingOptions.m_vbrMinBitRate = 112;
	}
	else if (l_index == 11)
	{
		m_encodingOptions.m_vbrMinBitRate = 128;
	}
	else if (l_index == 12)
	{
		m_encodingOptions.m_vbrMinBitRate = 144;
	}
	else if (l_index == 13)
	{
		m_encodingOptions.m_vbrMinBitRate = 160;
	}
	else if (l_index == 14)
	{
		m_encodingOptions.m_vbrMinBitRate = 192;
	}
	else if (l_index == 15)
	{
		m_encodingOptions.m_vbrMinBitRate = 256;
	}
	else if (l_index == 16)
	{
		m_encodingOptions.m_vbrMinBitRate = 320;
	}
}

//**********************************************************************************************************

void FormEncodingOptions :: _onVBRMaxChange( wxCommandEvent & p_event)
{
	int l_index = m_VBRMax->GetCurrentSelection();
	if (l_index == 0)
	{
		m_encodingOptions.m_vbrMaxBitRate = 8;
	}
	else if (l_index == 1)
	{
		m_encodingOptions.m_vbrMaxBitRate = 16;
	}
	else if (l_index == 2)
	{
		m_encodingOptions.m_vbrMaxBitRate = 24;
	}
	else if (l_index == 3)
	{
		m_encodingOptions.m_vbrMaxBitRate = 32;
	}
	else if (l_index == 4)
	{
		m_encodingOptions.m_vbrMaxBitRate = 40;
	}
	else if (l_index == 5)
	{
		m_encodingOptions.m_vbrMaxBitRate = 48;
	}
	else if (l_index == 6)
	{
		m_encodingOptions.m_vbrMaxBitRate = 56;
	}
	else if (l_index == 7)
	{
		m_encodingOptions.m_vbrMaxBitRate = 64;
	}
	else if (l_index == 8)
	{
		m_encodingOptions.m_vbrMaxBitRate = 80;
	}
	else if (l_index == 9)
	{
		m_encodingOptions.m_vbrMaxBitRate = 96;
	}
	else if (l_index == 10)
	{
		m_encodingOptions.m_vbrMaxBitRate = 112;
	}
	else if (l_index == 11)
	{
		m_encodingOptions.m_vbrMaxBitRate = 128;
	}
	else if (l_index == 12)
	{
		m_encodingOptions.m_vbrMaxBitRate = 144;
	}
	else if (l_index == 13)
	{
		m_encodingOptions.m_vbrMaxBitRate = 160;
	}
	else if (l_index == 14)
	{
		m_encodingOptions.m_vbrMaxBitRate = 192;
	}
	else if (l_index == 15)
	{
		m_encodingOptions.m_vbrMaxBitRate = 256;
	}
	else if (l_index == 16)
	{
		m_encodingOptions.m_vbrMaxBitRate = 320;
	}
}

//**********************************************************************************************************

void FormEncodingOptions :: _onVBRQualityChange( wxCommandEvent & p_event)
{
	m_encodingOptions.m_vbrQuality = m_VBRQuality->GetCurrentSelection();
}

//**********************************************************************************************************

void FormEncodingOptions :: _onEncodingQualityChange( wxScrollEvent & p_event)
{
	int l_position = m_encodingQuality->GetValue();
	if (l_position <= 2)
	{
		m_encodingOptions.m_encodingQuality = 3;
		m_label6->SetLabel( wxT( "High"));
	}
	else if (l_position <= 4)
	{
		m_label6->SetLabel( wxT( "Medium"));
		m_encodingOptions.m_encodingQuality = 2;
	}
	else if (l_position <= 7)
	{
		m_label6->SetLabel( wxT( "Low"));
		m_encodingOptions.m_encodingQuality = 1;
	}
	else
	{
		m_label6->SetLabel( wxT( "Fast Mode"));
		m_encodingOptions.m_encodingQuality = 0;
	}
}

//**********************************************************************************************************

void FormEncodingOptions :: _onSampleRateChange( wxCommandEvent & p_event)
{
	int l_index = m_sampleRate->GetCurrentSelection();
	if (l_index == 0)
	{
		m_encodingOptions.m_sampleRate = 48000;
	}
	else if (l_index == 1)
	{
		m_encodingOptions.m_sampleRate = 44100;
	}
	else if (l_index == 2)
	{
		m_encodingOptions.m_sampleRate = 32000;
	}
	else if (l_index == 3)
	{
		m_encodingOptions.m_sampleRate = 24000;
	}
	else if (l_index == 4)
	{
		m_encodingOptions.m_sampleRate = 22050;
	}
	else if (l_index == 5)
	{
		m_encodingOptions.m_sampleRate = 16000;
	}
}

//**********************************************************************************************************
