//******************************************************************************
#ifndef ___FormMain___
#define ___FormMain___
//******************************************************************************
#include <wx/frame.h>
#include "../Common.h"
//******************************************************************************
namespace JokersPlayer
{
	class FormMain : public wxFrame
	{
	private:
		wxPanel * m_container;
		wxSlider * m_volumeControl;
		wxStaticText * m_currentFile;
		wxStaticText * m_totalTime;
		wxStaticText * m_lblVolume;
		wxStaticText * m_lblNom;
		wxStaticText * LblTemps;
		wxCheckBox * m_CBLooped;
		wxCheckBox * m_CBRandom;
#ifdef WIN32
		ImageButton * m_btnPrevious;
		ImageButton * m_btnPlay;
		ImageButton * m_btnPause;
		ImageButton * m_btnStop;
		ImageButton * m_btnNext;

		ImageButton * m_btnAddFile;
		ImageButton * m_btnAddFolder;
		ImageButton * m_btnEncode;
#else
		wxBitmapButton * m_btnPrevious;
		wxBitmapButton * m_btnPlay;
		wxBitmapButton * m_btnPause;
		wxBitmapButton * m_btnStop;
		wxBitmapButton * m_btnNext;

		wxButton * m_btnAddFile;
		wxButton * m_btnAddFolder;
		wxButton * m_btnEncode;
#endif
		
		TaskBarIcon * m_trayIcon;

		wxArrayString m_filesList;
		wxArrayString m_vidFilesList;
		wxArrayString m_cdFilesList;
		wxArrayString * m_playingFilesList;
		wxArrayString m_playedFiles;

		wxString m_folder;
		wxString m_displayedMediaName;

		bool m_moveFile;
		bool m_looped;
		bool m_random;
		bool m_stopping;
		bool m_manualChange;
		bool m_playingCD;

		DesignMap m_designs;
		SimpleDesign * m_simpleDesign;
		FileStatus m_fileStatus;
		wxFileName * m_appDirectory;
		Log * m_log;

	public:
		wxSlider * m_mediaBar;
		wxString m_mediaName;
		PlayerStatus m_status;
		PlayerThread * m_playerThread;

	private:
		static bool sm_playingVideo;
		static bool sm_toPlay;
		static bool sm_stopping;
		static JokerCtrl * sm_videoPlayer;

	public:
		FormMain();
		~FormMain();
	                             
		void Initialise();
		void SetSimpleDesign( SimpleDesign * p_sd);

		bool LoadFile( const wxString & p_file);
		void EndOfMedia();
		void UpdateVideoSize( bool p_full, int p_width, int p_height);
		void FastForward();
		void FastBack();
		void SetFile( const wxString & p_file, bool p_loadIt=true, bool p_playIt=false);
		void PreviousFile();
		void Play();
		void Pause();
		void Stop();
		void NextFile();
		bool DeleteSelectedFile();
		void ExportPlayList( const wxString & p_destDir);
		void ImportPlayList( const wxString &  p_srcDir);
		void Randomise();
		void ChangeVolume( int p_change);
		void SetMediaTime( unsigned int p_mediaTime);
		void AddFile( const wxString & p_file);

		inline wxString GetMediaName() {return m_mediaName;}
		static inline JokerCtrl * GetJokerCtrl() { return sm_videoPlayer; }

	private:
		void _onCBLoopedClick		( wxCommandEvent & p_event);
		void _onCBRandomClick		( wxCommandEvent & p_event);
		void _onMediaBarChange		( wxScrollEvent & p_event);
		void _onVolumeControlChange	( wxScrollEvent & p_event);
		void _onFormKeyDown			( wxKeyEvent & p_event);
		void _onBtnAddFileClick		( wxCommandEvent & p_event);
		void _onBtnAddFolderClick	( wxCommandEvent & p_event);
		void _onBtnEncodeClick		( wxCommandEvent & p_event);
		void _onMoveWindow			( wxMoveEvent & p_event);
		void _onClose				( wxCloseEvent & p_event);
		void _onBtnPreviousClick	( wxCommandEvent & p_event);
		void _onBtnPlayClick		( wxCommandEvent & p_event);
		void _onBtnPauseClick		( wxCommandEvent & p_event);
		void _onBtnStopClick		( wxCommandEvent & p_event);
		void _onBtnNextClick		( wxCommandEvent & p_event);
		void _onIconize				( wxIconizeEvent & p_event);
		void _onMediaStop			( wxMediaEvent & p_event);
		void _onMediaLoaded			( wxMediaEvent & p_event);

		void		_findFiles		( const wxString & p_foldername);
		void		_readCfgFile	( const wxString & p_fileName);
		void		_readCfgStyles	( wxTextFile * p_file);
		wxColour	_getColour		( const wxString & p_sColor);
		void		_addFile		( const wxString & p_name);
		void		_selectNext		();

		DECLARE_EVENT_TABLE()
	};
}
//******************************************************************************
#endif
//******************************************************************************
