//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "../Log.h"

#include "FormPlaylist.h" 
#include "FormMain.h"
#include "FormSearch.h"
#include "FormTagEdit.h"
#include "../special/ImageButton.h"
#include <fmod_errors.h>
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
FormPlaylist * g_formPlaylist;
extern FormSearch * g_formSearch;
extern FormMain * g_formMain;
extern FormTagEdit * g_formTagEdit;
//**********************************************************************************************************
#define CHECKFMODERROR( X) _checkFMODError( X, __LINE__, __FILE__)
//**********************************************************************************************************
enum FormPlaylistIDs
{
	playlistList,
	playlistVidList,
	playlistCDList,
	playlistLoad,
	playlistSave,
	playlistRandomise,
	playlistSearch,
	playlistTypeSelector,
	playlistPlayCD,
	playlistPlayCD0,
	playlistPlayCD1,
	playlistPlayCD2,
	playlistPlayCD3,
	playlistPlayCD4,
	playlistPlayCD5,
	playlistPlayCD6,
	playlistPlayCD7
};
//**********************************************************************************************************
BEGIN_EVENT_TABLE( ListBox, wxListBox)
	EVT_RIGHT_UP(	ListBox::_onMouseRightUp)
END_EVENT_TABLE()
//**********************************************************************************************************

ListBox :: ListBox( wxWindow * parent, wxWindowID id, const wxPoint & pos, const wxSize & size,
					const wxArrayString & choices, long style)
	:	wxListBox( parent, id, pos, size, choices, style)
{
}

//**********************************************************************************************************

void ListBox :: _onMouseRightUp( wxMouseEvent & p_event)
{
	int l_item;
	if ((l_item = HitTest( p_event.GetPosition())) != wxNOT_FOUND)
	{
		wxString l_filePath = (* g_formPlaylist->m_shownFilesPaths)[l_item];
		g_formTagEdit->Init( l_filePath);
	}
}

//**********************************************************************************************************
BEGIN_EVENT_TABLE( FormPlaylist, wxFrame)
	EVT_KEY_DOWN(										FormPlaylist::_onFormKeyDown)
	EVT_BUTTON(					playlistLoad,			FormPlaylist::_onBtnLoadClick)
	EVT_BUTTON(					playlistSave,			FormPlaylist::_onBtnSaveClick)
	EVT_BUTTON(					playlistRandomise,		FormPlaylist::_onBtnRandomiseClick)
	EVT_BUTTON(					playlistSearch,			FormPlaylist::_onBtnSearchClick)
	EVT_BUTTON(					playlistPlayCD,			FormPlaylist::_onBtnPlayCD)
	EVT_NOTEBOOK_PAGE_CHANGED(	playlistTypeSelector,	FormPlaylist::_onTypeSelectorChange)
	EVT_LISTBOX(				playlistList,			FormPlaylist::_onSGFilesListSelect)
	EVT_LISTBOX(				playlistVidList,		FormPlaylist::_onSGVidFilesListSelect)
	EVT_LISTBOX(				playlistCDList,			FormPlaylist::_onSGCDFilesListSelect)
	EVT_LISTBOX_DCLICK(			playlistList,			FormPlaylist::_onSGFilesListDblClick)
	EVT_LISTBOX_DCLICK(			playlistVidList,		FormPlaylist::_onSGVidFilesListDblClick)
	EVT_LISTBOX_DCLICK(			playlistCDList,			FormPlaylist::_onSGCDFilesListDblClick)
	EVT_MENU(	playlistPlayCD0,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD1,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD2,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD3,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD4,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD5,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD6,						FormPlaylist::_onPlayCD)
	EVT_MENU(	playlistPlayCD7,						FormPlaylist::_onPlayCD)
END_EVENT_TABLE()
//**********************************************************************************************************

FormPlaylist :: FormPlaylist( wxWindow * p_parent, const wxPoint & p_position)
	:	wxFrame( p_parent, wxID_ANY, wxT( "Playlist"), p_position, wxSize( 296, 622), wxFRAME_TOOL_WINDOW | wxCAPTION | wxCLOSE_BOX | wxFRAME_FLOAT_ON_PARENT),
		m_selectedItem( -1),
		m_nbFiles( 0),
		m_nbVidFiles( 0),
		m_nbCDFiles( 0)
{
	g_formPlaylist = this;

	wxSize l_size = GetClientSize();
	wxArrayString l_choices;
	wxArrayString l_vidChoices;
	m_typeSelector = new wxNotebook( this, playlistTypeSelector, wxPoint( 0, 0), wxSize( 290, l_size.y - 56), wxNO_BORDER);
	m_musics = new wxPanel( m_typeSelector, wxID_ANY, wxPoint( 0, 0), m_typeSelector->GetClientSize() - wxSize( 0, 30));
	m_typeSelector->AddPage( m_musics, wxT( "Audio"));
	SGFilesList = new ListBox( m_musics, playlistList, wxPoint( 0, 0), m_musics->GetClientSize(), l_choices, wxLB_SINGLE | wxLB_NEEDED_SB);
	m_videos = new wxPanel( m_typeSelector, wxID_ANY, wxPoint( 0, 0), m_typeSelector->GetClientSize() - wxSize( 0, 30));
	m_typeSelector->AddPage( m_videos, wxT( "Video"));
	SGVidFilesList = new ListBox( m_videos, playlistVidList, wxPoint( 0, 0), m_videos->GetClientSize(), l_choices, wxLB_SINGLE | wxLB_NEEDED_SB);
	m_cds = new wxPanel( m_typeSelector, wxID_ANY, wxPoint( 0, 0), m_typeSelector->GetClientSize() - wxSize( 0, 30));
	m_typeSelector->AddPage( m_cds, wxT( "CD"));
	SGCDFilesList = new ListBox( m_cds, playlistCDList, wxPoint( 0, 0), m_cds->GetClientSize(), l_choices, wxLB_SINGLE | wxLB_NEEDED_SB);
#ifdef WIN32
	m_btnLoad = new ImageButton( this, playlistLoad, wxT( "Charger"), wxPoint( 8, 567), wxSize( 33, 29), g_buttonStyle);
	m_btnSave = new ImageButton( this, playlistSave, wxT( "Sauv."), wxPoint( 47, 567), wxSize( 33, 29), g_buttonStyle);
	m_btnRandomise = new ImageButton( this, playlistRandomise, wxT( "Rand."), wxPoint( 86, 567), wxSize( 33, 29), g_buttonStyle);
	m_btnSearch = new ImageButton( this, playlistSearch, wxT( "Chercher"), wxPoint( 125, 567), wxSize( 44, 29), g_buttonStyle);
	m_btnPlayCD = new ImageButton( this, playlistPlayCD, wxT( "Lire CD"), wxPoint( 220, 567), wxSize( 64, 29), g_buttonStyle);
#else
	m_btnLoad = new wxButton( this, playlistLoad, wxT( "Charger"), wxPoint( 8, 567), wxSize( 33, 29), g_buttonStyle);
	m_btnSave = new wxButton( this, playlistSave, wxT( "Sauv."), wxPoint( 47, 567), wxSize( 33, 29), g_buttonStyle);
	m_btnRandomise = new wxButton( this, playlistRandomise, wxT( "Rand."), wxPoint( 86, 567), wxSize( 33, 29), g_buttonStyle);
	m_btnSearch = new wxButton( this, playlistSearch, wxT( "Chercher"), wxPoint( 125, 567), wxSize( 44, 29), g_buttonStyle);
	m_btnPlayCD = new wxButton( this, playlistPlayCD, wxT( "Lire CD"), wxPoint( 220, 567), wxSize( 64, 29), g_buttonStyle);
#endif

	g_formSearch = new FormSearch( this);
	g_formSearch->Hide();
	g_formTagEdit = new FormTagEdit( this);
	g_formTagEdit->Hide();
	m_shownList = SGFilesList;
	m_shownSelectedItem = & m_selectedItem;
	m_shownCurrentFilePath = & m_currentFilePath;
	m_shownFilesPaths = & m_filesPaths;
	m_shownFilesList = & m_filesList;
}

//**********************************************************************************************************

void FormPlaylist :: SetSimpleDesign( SimpleDesign * p_sd)
{
	if (p_sd == NULL)
	{      
		Log::LogMessage( "ERROR : FormPlaylist :: SetSimpleDesign - Design Null");
		return;
	}
	m_simpleDesign = p_sd;

	SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_btnLoad->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnSave->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnRandomise->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnSearch->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_btnPlayCD->SetBackgroundColour( m_simpleDesign->m_1stColor);

#ifdef WIN32
	m_btnLoad->SetColours( m_simpleDesign->m_btnColours);
	m_btnLoad->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnSave->SetColours( m_simpleDesign->m_btnColours);
	m_btnSave->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnRandomise->SetColours( m_simpleDesign->m_btnColours);
	m_btnRandomise->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnSearch->SetColours( m_simpleDesign->m_btnColours);
	m_btnSearch->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnPlayCD->SetColours( m_simpleDesign->m_btnColours);
	m_btnPlayCD->SetFontColours( m_simpleDesign->m_btnFontColours);
#else
	m_btnLoad->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnSave->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnRandomise->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnSearch->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
	m_btnPlayCD->SetForegroundColour( m_simpleDesign->m_btnFontColours[jiENABLE]);
#endif

	m_typeSelector->SetBackgroundColour( m_simpleDesign->m_1stColor);
	m_typeSelector->SetForegroundColour( m_simpleDesign->m_1stColor);
	m_typeSelector->Refresh();

	SGFilesList->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	SGFilesList->SetBackgroundColour( m_simpleDesign->m_3rdColor);

	SGVidFilesList->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	SGVidFilesList->SetBackgroundColour( m_simpleDesign->m_3rdColor);

	SGCDFilesList->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	SGCDFilesList->SetBackgroundColour( m_simpleDesign->m_3rdColor);

	g_formSearch->SetSimpleDesign( m_simpleDesign);
	g_formTagEdit->SetSimpleDesign( m_simpleDesign);
	
	Refresh();
}

//**********************************************************************************************************

void FormPlaylist :: AddFile( const wxString & p_filePath)
{
	if (IsVideo( p_filePath))
	{
		_addFile( p_filePath, m_nbVidFiles, m_vidFilesPaths, m_vidFilesList,
				  SGVidFilesList, m_selectedVidItem, m_currentVidFilePath);
	}
	else if (IsMedia( p_filePath))
	{
		_addFile( p_filePath, m_nbFiles, m_filesPaths, m_filesList,
				  SGFilesList, m_selectedItem, m_currentFilePath);
	}
	else
	{
		_addFile( p_filePath, m_nbCDFiles, m_cdFilesPaths, m_cdFilesList,
				  SGCDFilesList, m_selectedCDItem, m_currentCDFilePath);
	}
}

//**********************************************************************************************************

void FormPlaylist :: PreviousFile()
{
	if (m_selectedItem > 0)
	{
		if (m_shownList == SGFilesList)
		{
			SGFilesList->SetSelection( --m_selectedItem);
			m_currentFilePath = SGFilesList->GetString( m_selectedItem);
		}
		else
		{
			SGVidFilesList->SetSelection( --m_selectedVidItem);
			m_currentVidFilePath = SGVidFilesList->GetString( m_selectedVidItem);
		}
    }
}

//**********************************************************************************************************

void FormPlaylist :: NextFile()
{     
	if (m_shownList == SGFilesList)
	{
		unsigned int l_count = static_cast <unsigned int>( SGFilesList->GetCount());
		if (m_selectedItem < l_count - 1)
		{
			SGFilesList->SetSelection(++m_selectedItem);
			m_currentFilePath = SGFilesList->GetString( m_selectedItem);
		}
	}
	else
	{
		unsigned int l_count = static_cast <unsigned int>( SGVidFilesList->GetCount());
		if (m_selectedVidItem < l_count - 1)
		{
			SGVidFilesList->SetSelection(++m_selectedVidItem);
			m_currentVidFilePath = SGVidFilesList->GetString( m_selectedVidItem);
		}
    }
}

//**********************************************************************************************************

void FormPlaylist :: SetSelected( const wxString & p_fileName)
{
	if (m_shownList == SGFilesList)
	{
		_setSelected( m_filesPaths, p_fileName, SGFilesList, m_selectedItem, m_currentFilePath);
	}
	else
	{                                    
		_setSelected( m_vidFilesPaths, p_fileName, SGVidFilesList, m_selectedVidItem, m_currentVidFilePath);
    }
}

//**********************************************************************************************************

bool FormPlaylist :: DeleteSelected()
{
	if (m_shownList == SGFilesList)
	{
		return _deleteSelected( SGFilesList, m_selectedItem, m_filesPaths, m_nbFiles);
	}
	else
	{
		return _deleteSelected( SGVidFilesList, m_selectedVidItem, m_vidFilesPaths, m_nbVidFiles);
	}
}

//**********************************************************************************************************

void FormPlaylist :: CleanFiles()
{
	m_filesPaths.clear();
	m_nbFiles = 0;
	SGFilesList->Clear();
	
	m_vidFilesPaths.clear();
	m_nbVidFiles = 0;
	SGVidFilesList->Clear();
}

//**********************************************************************************************************

void FormPlaylist :: _addFile( const wxString & p_filePath, int & p_nbFiles, wxArrayString & p_paths,
								wxArrayString & p_filesList, ListBox * p_grid, unsigned int & p_selectedItem,
								wxString & p_currentPath)
{
	wxString l_fileName = p_filePath;
	l_fileName.Replace( wxT( "\\"), wxT( "/"));
	size_t l_index = l_fileName.find_last_of( wxT( "/"));

	if (l_index > 0)
	{
		l_fileName = l_fileName.substr( l_index + 1);
	}

	if (l_fileName.empty())
	{
		Log::LogMessage( "ERROR : FormPlaylist :: _addVideoFile - Void File name");
		return;
	}
	if (p_nbFiles == 0)
	{                  
		p_paths.clear();
		p_filesList.clear();
		wxArrayString l_choices;
		p_grid->Set( l_choices);
		p_selectedItem = 0;
	}
	else
	{
		p_selectedItem++;
	}
	Log::LogMessage( wxT( "_addFile : ") + l_fileName); 
	p_nbFiles++;
	wxArrayString l_item;
	l_item.push_back( l_fileName);
	p_grid->Insert( l_fileName, p_selectedItem);
	p_grid->SetSelection( p_selectedItem);
	p_paths.push_back( p_filePath);
	p_filesList.push_back( l_fileName);
	p_currentPath = p_filePath;
}

//**********************************************************************************************************

void FormPlaylist :: _setSelected( wxArrayString & p_paths, const wxString & p_fileName, ListBox * p_list,
								    unsigned int & p_selectedItem, wxString & p_currentFilePath)
{     
	int l_index = p_paths.Index( p_fileName);
	if (l_index != wxNOT_FOUND && static_cast <unsigned int>( l_index) < p_list->GetCount())
	{
		p_selectedItem = l_index;
		p_list->SetSelection( p_selectedItem);
		p_currentFilePath = p_paths[l_index];
		g_formMain->SetFile( p_fileName);
	}
	else
	{
		p_selectedItem = -1;
	}
}

//**********************************************************************************************************

bool FormPlaylist :: _deleteSelected( ListBox * p_list, unsigned int & p_selectedItem,
									   wxArrayString & p_paths, int & p_nbFiles)
{
	unsigned int l_selection = static_cast <unsigned int>( p_list->GetSelection());
	if (l_selection == p_selectedItem)
	{
		wxString l_item = p_list->GetString( p_selectedItem);
		p_list->Delete( p_selectedItem);
		p_paths.RemoveAt( p_selectedItem);
		p_nbFiles--;
		if (p_paths.size() > 0)
		{
			if (p_selectedItem == p_list->GetCount())
			{
				p_selectedItem--;
			}
			p_list->SetSelection( p_selectedItem);
			return true;
		}
		else
		{
			wxArrayString l_choices;
			p_list->Set( l_choices);
			p_selectedItem = -1;
		}
	}
	Log::LogMessage( "ERROR : FormPlaylist :: _deleteSelected - Can't delete selected file");
	return false;
}

//**********************************************************************************************************

void FormPlaylist :: _onFormKeyDown( wxKeyEvent & p_event)
{
	switch (p_event.GetKeyCode())
	{
		case WXK_RIGHT:
			g_formMain->FastForward();
			break;
		case WXK_LEFT:
			g_formMain->FastBack();
			break;
		case WXK_UP:
			g_formMain->NextFile();
			break;
		case WXK_DOWN:
			g_formMain->PreviousFile();
			break;
		case WXK_NUMPAD_SUBTRACT:
			g_formMain->ChangeVolume(-5);
			break;
		case WXK_NUMPAD_ADD:
			g_formMain->ChangeVolume(5);
			break;
		case WXK_DELETE:
			if (g_formMain->DeleteSelectedFile())
			{         
				DeleteSelected();
			}
			break;
		default:
        	return;
	}
}

//**********************************************************************************************************

void FormPlaylist :: _onBtnLoadClick( wxCommandEvent & p_event)
{
	wxFileDialog * l_dialog = new wxFileDialog( this, wxT( "Choisissez un fichier"), wxEmptyString, wxEmptyString, 
												wxT( "Joker's Playlist|*.jpwxT( "));
	if (l_dialog->ShowModal() == wxID_OK)
	{
		g_formMain->ImportPlayList( l_dialog->GetPath());
	}
}

//**********************************************************************************************************

void FormPlaylist :: _onBtnSaveClick( wxCommandEvent & p_event)
{
	wxFileDialog * l_dialog = new wxFileDialog( this, wxT( "Choisissez un fichier"), wxEmptyString, wxEmptyString, 
												wxT( "Joker's Playlist|*.jpwxT( "), wxFD_SAVE);
	if (l_dialog->ShowModal() == wxID_OK)
	{
		g_formMain->ExportPlayList( l_dialog->GetPath());
	}
}

//**********************************************************************************************************

void FormPlaylist :: _onBtnRandomiseClick( wxCommandEvent & p_event)
{
	g_formMain->Randomise();
}

//**********************************************************************************************************

void FormPlaylist :: _onBtnPlayCD( wxCommandEvent & p_event)
{
	wxMenu * l_menu = new wxMenu();
	FMOD::System * l_system;
	FMOD::System_Create( & l_system);
	int l_nbCDRomDrives;
	l_system->getNumCDROMDrives( & l_nbCDRomDrives);
	char * l_driveName = new char[256];
	char * l_driveNameSCSI = new char[256];
	char * l_deviceName = new char[256];
	m_cdDrives.clear();
 	for (int i = 0 ; i < l_nbCDRomDrives ; i++)
	{
		l_system->getCDROMDriveName( i, l_driveName, 256, l_driveNameSCSI, 256, l_deviceName, 256);
		Log::LogMessage( l_driveName);
		l_menu->Append( playlistPlayCD0 + i, wxString( l_driveName, wxConvLibc));
		m_cdDrives.push_back( wxString( l_driveName, wxConvLibc));
	}
	l_system->close();
	l_system->release();
	PopupMenu( l_menu, m_btnPlayCD->GetPosition());
}

//**********************************************************************************************************

void FormPlaylist :: _onBtnSearchClick( wxCommandEvent & p_event)
{    
	g_formSearch->Show();
	if (m_shownList == SGFilesList)
	{
		g_formSearch->SetFilesList( m_filesList);
	}
	else
	{                                          
		g_formSearch->SetFilesList( m_vidFilesList);
    }
}

//**********************************************************************************************************

void FormPlaylist :: _onPlayCD( wxCommandEvent & p_event)
{
	g_formMain->Stop();
	int l_index = p_event.GetId() - playlistPlayCD0;
	FMOD::System * l_system;
	FMOD::Sound * l_sound;
	CHECKFMODERROR( FMOD::System_Create( & l_system));

	FMOD_OUTPUTTYPE l_outputMode[7] =
	{
		FMOD_OUTPUTTYPE_AUTODETECT,
		FMOD_OUTPUTTYPE_DSOUND,
		FMOD_OUTPUTTYPE_WINMM,
		FMOD_OUTPUTTYPE_ASIO,
		FMOD_OUTPUTTYPE_NOSOUND
	};

	for (size_t i = 0 ; i < 5 ; i ++)
	{
		CHECKFMODERROR( l_system->setOutput( l_outputMode[i]));

		if (CHECKFMODERROR( l_system->init( 4095, FMOD_INIT_NORMAL, 0)))
		{
			break;
		}
	}
	if (CHECKFMODERROR( l_system->createStream( m_cdDrives[l_index].char_str(), FMOD_DEFAULT, NULL, & l_sound)))
	{
		int l_tracksNumber = 0;
		if (CHECKFMODERROR( l_sound->getNumSubSounds( & l_tracksNumber)))
		{
			Log::LogMessage( "Tracks : %d", l_tracksNumber);
			wxString l_fileName;
			for (int i = 0 ; i < l_tracksNumber ; i++)
			{
				l_fileName = m_cdDrives[l_index];
				l_fileName << i;
				Log::LogMessage( l_fileName);
				g_formMain->AddFile( l_fileName);
			}
		}
		l_sound->release();
	}
	l_system->close();
	l_system->release();
}

//**********************************************************************************************************

void FormPlaylist :: _onSGFilesListDblClick( wxCommandEvent & p_event)
{
	if (SGFilesList->GetCount() == 0 || SGFilesList->GetSelection() == wxNOT_FOUND ||
		static_cast <unsigned int>( m_selectedItem) >= SGFilesList->GetCount())
	{
		return;
	}

	if (g_formMain->m_status == 3)
	{
		g_formMain->Stop();
	}

	g_formMain->SetFile( m_currentFilePath, true, true);
}

//**********************************************************************************************************

void FormPlaylist :: _onSGVidFilesListDblClick( wxCommandEvent & p_event)
{
	if (SGVidFilesList->GetCount() == 0 || SGVidFilesList->GetSelection() == wxNOT_FOUND ||
		static_cast <unsigned int>( m_selectedVidItem) >= SGVidFilesList->GetCount())
	{
		return;
	}

	if (g_formMain->m_status == 3)
	{
		g_formMain->Stop();
	}

	g_formMain->SetFile( m_currentVidFilePath, true, true);
}

//**********************************************************************************************************

void FormPlaylist :: _onSGCDFilesListDblClick( wxCommandEvent & p_event)
{
	if (SGCDFilesList->GetCount() == 0 || SGCDFilesList->GetSelection() == wxNOT_FOUND ||
		static_cast <unsigned int>( m_selectedCDItem) >= SGCDFilesList->GetCount())
	{
		return;
	}

	if (g_formMain->m_status == 3)
	{
		g_formMain->Stop();
	}

	g_formMain->SetFile( m_currentCDFilePath, true, true);
}

//**********************************************************************************************************

void FormPlaylist :: _onSGFilesListSelect( wxCommandEvent & p_event)
{
	if (SGFilesList->GetCount() == 0)
	{
		return;
	}

	int l_row = SGFilesList->GetSelection();
	if (static_cast <unsigned int>( l_row) < SGFilesList->GetCount() && l_row >= 0)
	{
		SGFilesList->SetSelection( l_row);
		m_selectedItem = l_row;
		m_currentFilePath = m_filesPaths[l_row];
		g_formMain->SetFile( m_currentFilePath, false);
	}
}

//**********************************************************************************************************

void FormPlaylist :: _onSGVidFilesListSelect( wxCommandEvent & p_event)
{
	if (SGVidFilesList->GetCount() == 0)
	{
		return;
	}

	int l_row = SGVidFilesList->GetSelection();
	if (static_cast <unsigned int>( l_row) < SGVidFilesList->GetCount() && l_row >= 0)
	{
		SGVidFilesList->SetSelection( l_row);
		m_selectedVidItem = l_row;
		m_currentVidFilePath = m_vidFilesPaths[l_row];
		g_formMain->SetFile( m_currentVidFilePath, false);
	}
}

//**********************************************************************************************************

void FormPlaylist :: _onSGCDFilesListSelect( wxCommandEvent & p_event)
{
	if (SGCDFilesList->GetCount() == 0)
	{
		return;
	}

	int l_row = SGCDFilesList->GetSelection();
	if (static_cast <unsigned int>( l_row) < SGCDFilesList->GetCount() && l_row >= 0)
	{
		SGCDFilesList->SetSelection( l_row);
		m_selectedCDItem = l_row;
		m_currentCDFilePath = m_cdFilesPaths[l_row];
		g_formMain->SetFile( m_currentCDFilePath, false);
	}
}

//**********************************************************************************************************

void FormPlaylist :: _onTypeSelectorChange( wxNotebookEvent & p_event)
{
	if (p_event.GetSelection() == 0)
	{
		m_shownList = SGFilesList;
		m_shownSelectedItem = & m_selectedItem;
		m_shownCurrentFilePath = & m_currentFilePath;
		m_shownFilesPaths = & m_filesPaths;
		m_shownFilesList = & m_filesList;
	}
	else if (p_event.GetSelection() == 1)
	{
		m_shownList = SGVidFilesList;
		m_shownSelectedItem = & m_selectedVidItem;
		m_shownCurrentFilePath = & m_currentVidFilePath;
		m_shownFilesPaths = & m_vidFilesPaths;
		m_shownFilesList = & m_vidFilesList;
    }
	else
	{
		m_shownList = SGCDFilesList;
		m_shownSelectedItem = & m_selectedCDItem;
		m_shownCurrentFilePath = & m_currentCDFilePath;
		m_shownFilesPaths = & m_cdFilesPaths;
		m_shownFilesList = & m_cdFilesList;
    }
}

//**********************************************************************************************************

bool FormPlaylist :: _checkFMODError( FMOD_RESULT p_result, unsigned int p_line, const char * p_file)
{
	if (p_result == FMOD_OK)
	{
		return true;
	}

	char * l_errorString = const_cast <char *>( FMOD_ErrorString( p_result));
	wxString l_msg = wxT( "FMOD error (");
	l_msg << p_result;
	l_msg += wxString( wxT( ") : [ ")) + wxString( l_errorString, wxConvLibc) + wxT( "] in \"") + wxString( p_file, wxConvLibc) + wxT( "\"@");
	l_msg << p_line;

	Log::LogMessage( l_msg);
	return false;
}

//**********************************************************************************************************
