//**********************************************************************************************************
#ifndef JPFormPlaylistH
#define JPFormPlaylistH
//**********************************************************************************************************
#include "../Common.h"
#include <wx/frame.h>
#include <wx/listbox.h>
#include <fmod.hpp>
//**********************************************************************************************************
namespace JokersPlayer
{
	class ListBox : public wxListBox
	{
	public:
		ListBox( wxWindow * parent, wxWindowID id, const wxPoint & pos, const wxSize & size,
				 const wxArrayString & choices, long style = 0);
	private:
		void _onMouseRightUp( wxMouseEvent & p_event);

		DECLARE_EVENT_TABLE()
	};

	class FormPlaylist : public wxFrame
	{
	private:
#ifdef WIN32
		ImageButton * m_btnLoad;
		ImageButton * m_btnSave;
		ImageButton * m_btnRandomise;
		ImageButton * m_btnSearch;
		ImageButton * m_btnPlayCD;
#else
		wxButton * m_btnLoad;
		wxButton * m_btnSave;
		wxButton * m_btnRandomise;
		wxButton * m_btnSearch;
		wxButton * m_btnPlayCD;
#endif
		wxNotebook * m_typeSelector;
		wxPanel * m_musics;
		wxPanel * m_videos;
		wxPanel * m_cds;

		ListBox * m_shownList;
		SimpleDesign * m_simpleDesign;
		unsigned int m_selectedItem;
		wxString m_currentFilePath;
		unsigned int m_selectedVidItem;
		wxString m_currentVidFilePath;
		unsigned int m_selectedCDItem;
		wxString m_currentCDFilePath;

		std::vector <wxString> m_cdDrives;

	public:
		ListBox * SGFilesList;
		ListBox * SGVidFilesList;
		ListBox * SGCDFilesList;

		int m_nbFiles;
		wxArrayString m_filesList;   
		wxArrayString m_filesPaths;
		int m_nbVidFiles;
		wxArrayString m_vidFilesList;
		wxArrayString m_vidFilesPaths;
		int m_nbCDFiles;
		wxArrayString m_cdFilesList;
		wxArrayString m_cdFilesPaths;

		int * m_nbShownFiles;
		unsigned int * m_shownSelectedItem;
		wxString * m_shownCurrentFilePath;
		wxArrayString * m_shownFilesPaths;
		wxArrayString * m_shownFilesList;

	public:
		FormPlaylist( wxWindow * p_parent, const wxPoint & p_position=wxPoint( 0, 185));
		void SetSimpleDesign( SimpleDesign * p_sd);
		void AddFile( const wxString & p_filePath);
		void PreviousFile();
		void NextFile();
		void SetSelected( const wxString & p_filename);
		bool DeleteSelected();
		void CleanFiles();

	private:
		void _setSelected( wxArrayString & p_paths, const wxString & p_fileName,
						   ListBox * p_list, unsigned int & p_selectedItem,
						   wxString & p_currentFilePath);
		bool _deleteSelected( ListBox * p_list, unsigned int & p_selectedItem,
							  wxArrayString & p_paths, int & p_nbFiles);
		void _addFile( const wxString & p_filePath, int & p_nbFiles, wxArrayString & p_paths,
					   wxArrayString & p_filesList, ListBox * p_grid,
					   unsigned int & p_selectedItem, wxString & p_currentPath);
		
		void _onFormKeyDown				( wxKeyEvent & p_event);
		void _onBtnLoadClick			( wxCommandEvent & p_event);
		void _onBtnSaveClick			( wxCommandEvent & p_event);
		void _onBtnRandomiseClick		( wxCommandEvent & p_event);
		void _onBtnSearchClick			( wxCommandEvent & p_event);
		void _onBtnPlayCD				( wxCommandEvent & p_event);
		void _onSGFilesListDblClick		( wxCommandEvent & p_event);
		void _onSGVidFilesListDblClick	( wxCommandEvent & p_event);
		void _onSGCDFilesListDblClick	( wxCommandEvent & p_event);
		void _onSGFilesListSelect		( wxCommandEvent & p_event);
		void _onSGVidFilesListSelect	( wxCommandEvent & p_event);
		void _onSGCDFilesListSelect		( wxCommandEvent & p_event);
		void _onTypeSelectorChange		( wxNotebookEvent & p_event);
		void _onPlayCD					( wxCommandEvent & p_event);

		bool _checkFMODError( FMOD_RESULT p_result, unsigned int p_line, const char * p_file);

	public:
		inline wxString			GetSelectedList		() { return (m_shownList == SGFilesList ? wxT( "Audio") : (m_shownList == SGVidFilesList ? wxT( "Video") : wxT( "CD"))); }
		inline const wxString &	GetSelectedFile		() { return m_currentFilePath; }
		inline const wxString &	GetSelectedVidFile	() { return m_currentVidFilePath; }
		inline const wxString &	GetSelectedCDFile	() { return m_currentCDFilePath; }

		DECLARE_EVENT_TABLE()
	};
}
//**********************************************************************************************************
#endif            
//**********************************************************************************************************
