//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "../Log.h"

#include "FormSearch.h"
#include "FormPlaylist.h"
#include "FormMain.h"
#include "../special/ImageButton.h"
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
FormSearch * g_formSearch;
extern FormPlaylist * g_formPlaylist;
extern FormMain * g_formMain;
//**********************************************************************************************************
enum FormSearchIDs
{
	searchEdit,
	searchList,
	searchCancel
};
//**********************************************************************************************************
BEGIN_EVENT_TABLE( FormSearch, wxFrame)
	EVT_BUTTON(			searchCancel,	FormSearch::_onBtnCancelClick)
	EVT_TEXT(			searchEdit,		FormSearch::_onEditSearchChange)
	EVT_LISTBOX(		searchList,		FormSearch::_onLBSearchSelect)
	EVT_LISTBOX_DCLICK(	searchList,		FormSearch::_onLBSearchDblClick)
END_EVENT_TABLE()
//**********************************************************************************************************

FormSearch :: FormSearch( wxWindow * p_parent)
	:	wxFrame( p_parent, wxID_ANY, wxT( "Rechercher"), wxPoint( 0, 0), wxSize( 285, 341), wxFRAME_TOOL_WINDOW | wxCAPTION | wxCLOSE_BOX | wxFRAME_FLOAT_ON_PARENT),
		m_simpleDesign( NULL),
		m_selectedItem( -1)
{
	g_formSearch = this;
	m_editSearch = new wxTextCtrl( this, searchEdit, wxEmptyString, wxPoint( 0, 0), wxSize( 276, 21));
	wxArrayString l_choices;
	m_LBSearch = new wxListBox( this, searchList, wxPoint( 0, 27), wxSize( 276, 254), l_choices, wxLB_SINGLE | wxLB_NEEDED_SB);
#ifdef WIN32
	m_btnCancel = new ImageButton( this, searchCancel, wxT( "Annuler"), wxPoint( 104, 287), wxSize( 65, 25), g_buttonStyle);
#else
	m_btnCancel = new wxButton( this, searchCancel, wxT( "Annuler", wxPoint( 104, 287), wxSize( 65, 25), g_buttonStyle);
#endif
}

//**********************************************************************************************************

void FormSearch :: SetSimpleDesign (SimpleDesign * p_sd)
{            
	if (p_sd == NULL)
	{
		Log::LogMessage( "ERROR : FormSearch :: SetSimpleDesign - Design NulwxT( ");
		return;
	}
	m_simpleDesign = p_sd;

	SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_btnCancel->SetBackgroundColour( m_simpleDesign->m_1stColor);

#ifdef WIN32
	m_btnCancel->SetColours( m_simpleDesign->m_btnColours);
	m_btnCancel->SetFontColours( m_simpleDesign->m_btnFontColours);
#endif

	m_LBSearch->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_LBSearch->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);

	m_editSearch->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_editSearch->SetForegroundColour( m_simpleDesign->m_3rdTxtColor);
	
	Refresh();
}

//**********************************************************************************************************

void FormSearch :: _onBtnCancelClick( wxCommandEvent & p_event)
{
	Hide();
}

//**********************************************************************************************************

void FormSearch :: SetFilesList( wxArrayString p_list)
{
	if (p_list == NULL)
	{
		Log::LogMessage( "ERROR : FormSearch :: SetFilesList - Null List");
    	return;
	}
	m_filesList.clear();
	m_displayedList.clear();

	for (size_t i = 0 ; i < p_list.size() ; i++)
	{
		m_filesList.push_back( p_list[i]);
		m_displayedList.push_back( p_list[i]);
	}

	UpdateListBox();
}

//**********************************************************************************************************

void FormSearch :: UpdateListBox()
{
	m_LBSearch->Set( m_displayedList);
}

//**********************************************************************************************************

void FormSearch :: _onEditSearchChange( wxCommandEvent & p_event)
{
	/**/
	if (m_filesList == NULL)
	{
		return;
	}
	m_displayedList.clear();
	for (size_t i = 0 ; i < m_filesList.size() ; i++)
	{
		m_displayedList.push_back( m_filesList[i]);
	}
	if (m_displayedList.size() == 0)
	{
		return;
	}

	wxString l_text = m_editSearch->GetValue().MakeLower();
	l_text = l_text.Trim();
	wxArrayString l_words = Split(l_text, ' ');
	size_t l_nbWords = l_words.size();
	wxString l_file;
	if (l_words != NULL)
	{
		wxArrayString::iterator l_it;
		for (size_t i = 0 ; i < l_nbWords && m_displayedList.size() > 0 ; i++)
		{
			l_it = m_displayedList.begin();
			l_file = (* l_it).Trim().MakeLower();
			if ( ! l_file.empty())
			{
				if (l_file.Find( l_words[i]) == wxNOT_FOUND)
				{
					m_displayedList.erase( l_it);
				}
			}
			++l_it;

			while (m_displayedList.size() > 0 && l_it != m_displayedList.end())
			{
				l_file = (* l_it).Trim().MakeLower();
				if ( ! l_file.empty())
				{
					if (l_file.Find( l_words[i]) == wxNOT_FOUND)
					{
						m_displayedList.erase( l_it);
					}
				}
			}

			l_it = m_displayedList.begin();
			l_file = (* l_it).Trim().MakeLower();
			if ( ! l_file.empty())
			{
				if (l_file.Find( l_words[i]) == wxNOT_FOUND)
				{
					m_displayedList.erase( l_it);
				}
			}
		}
		l_words.clear();
		UpdateListBox();
	}
}

//**********************************************************************************************************

wxArrayString FormSearch :: Split (wxString p_txt, char p_separator)
{
	if (p_txt.empty())
	{        
		Log::LogMessage( "ERROR : FormSearch :: Split - Void text");
		return NULL;
	}
	wxArrayString l_tokens;
	wxString l_token;
	unsigned int l_tokenIndex = 0;
	size_t l_txtIndex = 0;
	while (l_txtIndex < p_txt.Length())
	{
		if (p_txt[l_txtIndex] == p_separator)
		{
			l_tokens.push_back( l_token);
			l_token.clear();
			l_tokenIndex++;
		}
		else
		{
			l_token += p_txt[l_txtIndex];
		}
		l_txtIndex++;
	}
    return l_tokens;
}

//**********************************************************************************************************

void FormSearch :: _onLBSearchDblClick( wxCommandEvent & p_event)
{
	if (m_selectedItem >= 0)
	{
		int l_row =	g_formPlaylist->m_filesList.Index( m_currentFile);
		wxString l_currentFilePath = g_formPlaylist->m_filesPaths.Item(l_row);
		g_formPlaylist->SGFilesList->SetSelection( l_row);
		Log::LogMessage( "FormSearch :: LBSearchDblClick - %d", l_row);
		if (g_formMain->m_status == STATUS_PLAY)
		{
			g_formMain->Stop();
		}                               
		Log::LogMessage( wxT( "FormSearch :: LBSearchDblClick - ") + l_currentFilePath);
		g_formMain->SetFile(l_currentFilePath, true, true);
	}
}

//**********************************************************************************************************

void FormSearch :: _onLBSearchSelect( wxCommandEvent & p_event)
{
	if (m_LBSearch->GetSelection() != wxNOT_FOUND)
	{
		m_selectedItem = m_LBSearch->GetSelection();
		m_currentFile = m_displayedList[m_selectedItem];
		Log::LogMessage( wxT( "FormSearch :: LBSearchMouseUp - ") + m_currentFile);
	}
	else
	{
		m_selectedItem = -1;
		m_currentFile.clear();
    }
}

//**********************************************************************************************************
