//**********************************************************************************************************
#include "PrecompiledHeader.h"
#include "../Log.h"

#include "FormVideo.h"
#include "../other/JokersCtrl.h"
#include "FormMain.h"
#include "../special/ImageButton.h"
#include "../main/JokersPlayer.h"
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
FormVideo * g_formVideo;
extern FormMain * g_formMain;
const int g_videoFrameStyle = wxCAPTION | wxFRAME_NO_TASKBAR | wxTHICK_FRAME | wxCLOSE_BOX | wxSYSTEM_MENU | wxFRAME_FLOAT_ON_PARENT | wxSTAY_ON_TOP;
const int g_timerTime = 1000;
//**********************************************************************************************************
enum FormVideoID
{
	videoTimer,
	videoPrevious,
	videoPlay,
	videoPause,
	videoStop,
	videoNext,
	videoTime,
	controlHide
};
//**********************************************************************************************************
BEGIN_EVENT_TABLE( FormVideo, wxFrame)
	EVT_LEFT_DCLICK(					FormVideo::_onVideoPanelDblClick)
	EVT_CLOSE(							FormVideo::_onFormClose)
	EVT_SIZE(							FormVideo::_onFormResize)
	EVT_KEY_DOWN(						FormVideo::_onFormKeyDown)
	EVT_MOTION(							FormVideo::_onFormMouseMove)

	EVT_TIMER(			videoTimer,		FormVideo::_onTimerCursorOnFullScreenTimer)
	EVT_TIMER(			controlHide,	FormVideo::_onTimerControlOnFullScreenTimer)
	EVT_BUTTON(			videoPrevious,	FormVideo::_onBtnPreviousClick)
	EVT_BUTTON(			videoPlay,		FormVideo::_onBtnPlayClick)
	EVT_BUTTON(			videoPause,		FormVideo::_onBtnPauseClick)
	EVT_BUTTON(			videoStop,		FormVideo::_onBtnStopClick)
	EVT_BUTTON(			videoNext,		FormVideo::_onBtnNextClick)
	EVT_COMMAND_SCROLL(	videoTime,		FormVideo::_onMediaBarChange)
END_EVENT_TABLE()
//**********************************************************************************************************

FormVideo :: FormVideo( wxWindow * p_parent)
	:	wxFrame( p_parent, wxID_ANY, wxT( "Video")),// g_videoFrameStyle),
		m_fullScreen( false)
{
	g_formVideo = this;

	m_timerCursorOnFullScreen = new wxTimer( this, videoTimer);
	m_timerControlOnFullScreen = new wxTimer( this, controlHide);

	m_fullScreenControls = new wxPanel( g_formMain->GetJokerCtrl(), wxID_ANY, wxPoint( 0, 60), wxSize( 200, 40));
	m_fullScreenControls->Hide();
	wxImage l_images[5];
	wxFileName * l_appDirectory = new wxFileName( wxGetApp().argv[0]);
	l_images[0] = wxImage( l_appDirectory->GetPath() + wxT( "/rsc/PNGPrevious.png"));
	l_images[1] = wxImage( l_appDirectory->GetPath() + wxT( "/rsc/PNGPlay.png"));
	l_images[2] = wxImage( l_appDirectory->GetPath() + wxT( "/rsc/PNGPause.png"));
	l_images[3] = wxImage( l_appDirectory->GetPath() + wxT( "/rsc/PNGStop.png"));
	l_images[4] = wxImage( l_appDirectory->GetPath() + wxT( "/rsc/PNGNext.png"));
	m_btnPrevious = new ImageButton( m_fullScreenControls, videoPrevious, wxEmptyString, wxPoint( 0, 0), wxSize( 40, 40), g_buttonStyle);
	m_btnPrevious->SetImageEnable( l_images[0]);
	m_btnPlay = new ImageButton( m_fullScreenControls, videoPlay, wxEmptyString, wxPoint( 40, 0), wxSize( 40, 40), g_buttonStyle);
	m_btnPlay->SetImageEnable( l_images[1]);
	m_btnPause = new ImageButton( m_fullScreenControls, videoPause, wxEmptyString, wxPoint( 80, 0), wxSize( 40, 40), g_buttonStyle);
	m_btnPause->SetImageEnable( l_images[2]);
	m_btnStop = new ImageButton( m_fullScreenControls, videoStop, wxEmptyString, wxPoint( 120, 0), wxSize( 40, 40), g_buttonStyle);
	m_btnStop->SetImageEnable( l_images[3]);
	m_btnNext = new ImageButton( m_fullScreenControls, videoNext, wxEmptyString, wxPoint( 160, 0), wxSize( 40, 40), g_buttonStyle);
	m_btnNext->SetImageEnable( l_images[4]);
	m_mediaBar = new wxSlider( m_fullScreenControls, videoTime, 0, 0, 1000, wxPoint( 200, 0), wxSize( 200, 40));
}

//**********************************************************************************************************

void FormVideo :: SetSimpleDesign( SimpleDesign * p_sd)
{
	if (p_sd == NULL)
	{
		return;
	}
	m_simpleDesign = p_sd;

	SetBackgroundColour( m_simpleDesign->m_1stColor);

	m_btnPrevious->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_btnPrevious->SetColours( m_simpleDesign->m_btnColours);
	m_btnPrevious->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnPlay->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_btnPlay->SetColours( m_simpleDesign->m_btnColours);
	m_btnPlay->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnPause->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_btnPause->SetColours( m_simpleDesign->m_btnColours);
	m_btnPause->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnStop->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_btnStop->SetColours( m_simpleDesign->m_btnColours);
	m_btnStop->SetFontColours( m_simpleDesign->m_btnFontColours);
	m_btnNext->SetBackgroundColour( m_simpleDesign->m_3rdColor);
	m_btnNext->SetColours( m_simpleDesign->m_btnColours);
	m_btnNext->SetFontColours( m_simpleDesign->m_btnFontColours);

	m_mediaBar->SetBackgroundColour( m_simpleDesign->m_3rdColor);

	Refresh();
}

//**********************************************************************************************************

void FormVideo :: _onPaint( wxPaintEvent & p_event)
{
	g_formMain->GetJokerCtrl()->InvalidateBestSize();
}

//**********************************************************************************************************

void FormVideo :: _onFormClose( wxCloseEvent & p_event)
{
	g_formMain->GetJokerCtrl()->Stop();
	Hide();
}

//**********************************************************************************************************

void FormVideo :: _onFormResize( wxSizeEvent & p_event)
{
	g_formMain->UpdateVideoSize( m_fullScreen, GetClientSize().x, GetClientSize().y);
	p_event.Skip();
}

//**********************************************************************************************************

void FormVideo :: _onFormKeyDown( wxKeyEvent & p_event)
{
	int Key = p_event.GetKeyCode();
	if (Key == VK_RIGHT)
	{
		g_formMain->FastForward();
	}
	else if (Key == VK_LEFT)
	{
		g_formMain->FastBack();
	}
	else if (Key == VK_PRIOR)
	{
		g_formMain->NextFile();
	}
	else if (Key == VK_NEXT)
	{
		g_formMain->PreviousFile();
	}
	else if (Key == VK_SPACE)
	{
		if (g_formMain->m_status == STATUS_PLAY)
		{
			g_formMain->Pause();
		}
		else if (g_formMain->m_status == STATUS_PAUSE)
		{
			g_formMain->Play();
		}
	}
	else if (Key == VK_SUBTRACT)
	{
		g_formMain->ChangeVolume(-5);
	}
	else if (Key == VK_ADD)
	{
		g_formMain->ChangeVolume(5);
	}
	else if (Key == VK_RETURN)
	{
		ToggleFullScreen( true);
	}
	else if (Key == VK_ESCAPE)
	{
		if (m_fullScreen)
		{
			ToggleFullScreen(false);
			RefreshScreen ();
        }
	}
}

//**********************************************************************************************************

void FormVideo :: ToggleFullScreen( bool p_full)
{
	m_fullScreen = p_full;
	RefreshScreen();
}

//**********************************************************************************************************

void FormVideo :: RefreshScreen()
{
	if (m_fullScreen)
	{
		GetPosition( & m_left, & m_top);
		SetPosition( wxPoint( 0, 0));
		SetWindowStyle( wxFRAME_TOOL_WINDOW | wxFRAME_NO_TASKBAR | wxBORDER_NONE | wxFRAME_FLOAT_ON_PARENT);
		int l_width, l_height;
		wxDisplaySize( & l_width, & l_height);
		SetSize( wxSize( l_width, l_height));
		g_formMain->GetJokerCtrl()->SetSize( GetClientSize());
		m_timerCursorOnFullScreen->Start( g_timerTime, true);
		m_fullScreenControls->SetPosition( wxPoint( (l_width - 400) / 2, l_height - 40));
		m_fullScreenControls->SetSize( wxSize( 400, 40));
		m_fullScreenControls->Show();
	}
	else
	{                    
		m_timerCursorOnFullScreen->Stop();
		SetWindowStyle( g_videoFrameStyle);
		SetSize( wxSize( m_dimension.x + 6, m_dimension.y + 6));
		SetPosition( wxPoint( m_left, m_top));
		g_formMain->GetJokerCtrl()->SetSize( wxSize( m_dimension.x, m_dimension.y));
		SetCursor( * wxSTANDARD_CURSOR);
		g_formMain->GetJokerCtrl()->SetCursor( * wxSTANDARD_CURSOR);
		m_fullScreenControls->SetCursor( * wxSTANDARD_CURSOR);
		m_fullScreenControls->Hide();
	}
	g_formMain->UpdateVideoSize( m_fullScreen, GetClientSize().x, GetClientSize().y);
}                        

//**********************************************************************************************************

void FormVideo :: SetDimensions( const wxSize & p_dim)
{
	m_dimension = p_dim;
	SetSize( m_dimension.x, m_dimension.y);
}

//**********************************************************************************************************

void FormVideo :: StartTimer()
{
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************

void FormVideo :: _onVideoPanelDblClick( wxMouseEvent & p_event)
{
	ToggleFullScreen( ! m_fullScreen);
}

//**********************************************************************************************************

void FormVideo :: _onTimerCursorOnFullScreenTimer( wxTimerEvent & p_event)
{
	if (m_fullScreen)
	{
		m_timerControlOnFullScreen->Start( 50);
		m_fullScreenControls->Hide();
		SetCursor( wxCURSOR_BLANK);
		g_formMain->GetJokerCtrl()->SetCursor( wxCURSOR_BLANK);
		m_fullScreenControls->SetCursor( wxCURSOR_BLANK);
	}
}

//**********************************************************************************************************

void FormVideo :: _onTimerControlOnFullScreenTimer( wxTimerEvent & p_event)
{
	m_fullScreenControls->SetPosition( m_fullScreenControls->GetPosition() + wxPoint( 0, 2));
	int l_width, l_height;
	wxDisplaySize( & l_width, & l_height);
	if (m_fullScreenControls->GetPosition().y >= l_height)
	{
		m_timerControlOnFullScreen->Stop();
		m_fullScreenControls->Hide();
		m_fullScreenControls->SetPosition( wxPoint( (l_width - 400) / 2, l_height - 40));
	}
}

//**********************************************************************************************************

void FormVideo :: _onFormMouseMove( wxMouseEvent & p_event)
{
	if (m_fullScreen)
	{
		m_fullScreenControls->Show();
		SetCursor( * wxSTANDARD_CURSOR);
		g_formMain->GetJokerCtrl()->SetCursor( * wxSTANDARD_CURSOR);
		m_fullScreenControls->SetCursor( * wxSTANDARD_CURSOR);
		m_timerCursorOnFullScreen->Start( g_timerTime, true);
	}
}

//**********************************************************************************************************

void FormVideo :: _onBtnPreviousClick( wxCommandEvent & p_event)
{
	g_formMain->PreviousFile();
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************

void FormVideo :: _onBtnPlayClick( wxCommandEvent & p_event)
{
	if (g_formMain->m_status == STATUS_PAUSE)
	{
		g_formMain->Play();
	}
	else if (g_formMain->m_status != STATUS_PLAY)
	{
		g_formMain->SetFile( g_formMain->m_mediaName, true, true);
	}
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************

void FormVideo :: _onBtnPauseClick( wxCommandEvent & p_event)
{
	g_formMain->Pause();
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************

void FormVideo :: _onBtnStopClick( wxCommandEvent & p_event)
{
	g_formMain->Stop();
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************

void FormVideo :: _onBtnNextClick( wxCommandEvent & p_event)
{
	g_formMain->NextFile();
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************

void FormVideo :: _onMediaBarChange( wxScrollEvent & p_event)
{
	g_formMain->GetJokerCtrl()->Seek( m_mediaBar->GetValue());
	m_timerCursorOnFullScreen->Start( g_timerTime, true);
}

//**********************************************************************************************************