//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "TaskBarIcon.h"
#include "FormMain.h"
#include "FormPlaylist.h"
#include "../Log.h"
#include <fmod_errors.h>
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
enum TaskBarIconIDs
{
	taskbarPrevious,
	taskbarPlay,
	taskbarPause,
	taskbarStop,
	taskbarNext,
	taskbarPlayCD,
	taskbarPlayCD0,
	taskbarPlayCD1,
	taskbarPlayCD2,
	taskbarPlayCD3,
	taskbarPlayCD4,
	taskbarPlayCD5,
	taskbarPlayCD6,
	taskbarPlayCD7,
	taskbarPlayCD8,
};
//**********************************************************************************************************
BEGIN_EVENT_TABLE( TaskBarIcon, wxTaskBarIcon)
	EVT_TASKBAR_LEFT_DCLICK(		TaskBarIcon::_onTrayRightDClick)
	EVT_MENU(	taskbarPrevious,	TaskBarIcon::_onPrevious)
	EVT_MENU(	taskbarPlay,		TaskBarIcon::_onPlay)
	EVT_MENU(	taskbarPause,		TaskBarIcon::_onPause)
	EVT_MENU(	taskbarStop,		TaskBarIcon::_onStop)
	EVT_MENU(	taskbarNext,		TaskBarIcon::_onNext)
	EVT_MENU(	taskbarPlayCD0,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD1,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD2,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD3,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD4,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD5,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD6,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD7,		TaskBarIcon::_onPlayCD)
	EVT_MENU(	taskbarPlayCD8,		TaskBarIcon::_onPlayCD)
END_EVENT_TABLE()
//**********************************************************************************************************
extern FormMain * g_formMain;
extern FormPlaylist * g_formPlaylist;
//**********************************************************************************************************
#define CHECKFMODERROR( X) _checkFMODError( X, __LINE__, __FILE__)
//**********************************************************************************************************

TaskBarIcon :: TaskBarIcon()
	:	wxTaskBarIcon()
{
}

//**********************************************************************************************************

wxMenu * TaskBarIcon :: CreatePopupMenu()
{
	wxMenu * l_menu = new wxMenu;
	l_menu->Append( taskbarPrevious, wxT( "Précédent"));
	l_menu->Append( taskbarPlay, wxT( "Lire"));
	l_menu->Append( taskbarPause, wxT( "Pause"));
	l_menu->Append( taskbarStop, wxT( "Stop"));
	l_menu->Append( taskbarNext, wxT( "Suivant"));
	wxMenu * l_cdMenu = new wxMenu;
	FMOD::System * l_system;
	FMOD::System_Create( & l_system);
	int l_nbCDRomDrives;
	l_system->getNumCDROMDrives( & l_nbCDRomDrives);
	char * l_driveName = new char[256];
	char * l_driveNameSCSI = new char[256];
	char * l_deviceName = new char[256];
	m_cdDrives.clear();
	for (int i = 0 ; i < l_nbCDRomDrives ; i++)
	{
		l_system->getCDROMDriveName( i, l_driveName, 256, l_driveNameSCSI, 256, l_deviceName, 256);
		l_cdMenu->Append( taskbarPlayCD0 + i, wxString( l_driveName, wxConvLibc));
		m_cdDrives.push_back( wxString( l_driveName, wxConvLibc));
	}
	l_menu->AppendSubMenu( l_cdMenu, wxT( "PlayCD"));
	l_system->close();
	l_system->release();
	return l_menu;
}

//**********************************************************************************************************

void TaskBarIcon :: _onTrayRightDClick( wxTaskBarIconEvent & p_event)
{
	if (g_formMain->IsIconized())
	{
		wxIconizeEvent l_event = wxIconizeEvent( 0, false);
		g_formMain->ProcessEvent( l_event);
	}
}

//**********************************************************************************************************

void TaskBarIcon :: _onPrevious( wxCommandEvent & p_event)
{
	g_formMain->PreviousFile();
}

//**********************************************************************************************************

void TaskBarIcon :: _onPlay( wxCommandEvent & p_event)
{
	g_formMain->Play();
}

//**********************************************************************************************************

void TaskBarIcon :: _onPause( wxCommandEvent & p_event)
{
	g_formMain->Pause();
}

//**********************************************************************************************************

void TaskBarIcon :: _onStop( wxCommandEvent & p_event)
{
	g_formMain->Stop();
}

//**********************************************************************************************************

void TaskBarIcon :: _onNext( wxCommandEvent & p_event)
{
	g_formMain->NextFile();
}

//**********************************************************************************************************

void TaskBarIcon :: _onPlayCD( wxCommandEvent & p_event)
{
	g_formMain->Stop();
	int l_index = p_event.GetId() - taskbarPlayCD0;
	FMOD::System * l_system;
	FMOD::Sound * l_sound;
	CHECKFMODERROR( FMOD::System_Create( & l_system));

	FMOD_OUTPUTTYPE l_outputMode[7] =
	{
		FMOD_OUTPUTTYPE_AUTODETECT,
		FMOD_OUTPUTTYPE_DSOUND,
		FMOD_OUTPUTTYPE_WINMM,
		FMOD_OUTPUTTYPE_ASIO,
		FMOD_OUTPUTTYPE_NOSOUND
	};

	for (size_t i = 0 ; i < 5 ; i ++)
	{
		CHECKFMODERROR( l_system->setOutput( l_outputMode[i]));

		if (CHECKFMODERROR( l_system->init( 4095, FMOD_INIT_NORMAL, 0)))
		{
			break;
		}
	}
	CHECKFMODERROR( l_system->createStream( m_cdDrives[l_index].char_str(), FMOD_DEFAULT, NULL, & l_sound));
	int l_tracksNumber = 0;
	CHECKFMODERROR( l_sound->getNumSubSounds( & l_tracksNumber));
	wxString l_fileName;
	for (int i = 0 ; i < l_tracksNumber ; i++)
	{
		l_fileName = m_cdDrives[l_index];
		l_fileName << i;
		g_formPlaylist->AddFile( l_fileName);
	}
	l_sound->release();
	l_system->close();
	l_system->release();
}

//**********************************************************************************************************

bool TaskBarIcon :: _checkFMODError( FMOD_RESULT p_result, unsigned int p_line, const char * p_file)
{
	if (p_result == FMOD_OK)
	{
		return true;
	}

	char * l_errorString = const_cast <char *>( FMOD_ErrorString( p_result));
	wxString l_msg = wxT( "FMOD error (");
	l_msg << p_result;
	l_msg += wxString( wxT( ") : [ ")) + wxString( l_errorString, wxConvLibc) + wxT( "] in \"") + wxString( p_file, wxConvLibc) + wxT( "\"@");
	l_msg << p_line;

	Log::LogMessage( l_msg);
	return false;
}

//**********************************************************************************************************
