//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "../Log.h"

#include "EncoderThread.h"
#include "../gui/FormEncode.h"
#include "../gui/FormEncodingOptions.h"

#define _BLADEDLL
#ifdef WIN32
#	include <BladeMP3EncDLL.h>
#else
#	include "BladeMP3EncDLL.h"
#endif
#include "wavformat.h"
#include <lame.h>
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
extern FormEncode * g_formEncode;
//**********************************************************************************************************

EncoderThread :: EncoderThread( EncodingOptions * p_options, wxString p_inPath, wxString p_outPath)
	:	wxThread(),
		m_inFileName( p_inPath),
		m_outFileName( p_outPath),
		m_encodingOptions( p_options)
{
	g_formEncode->m_status->SetRange( 100);
	g_formEncode->m_status->SetValue( 0);
}

//**********************************************************************************************************

void * EncoderThread :: Entry()
{
	Log::LogMessage( "EncoderThread :: Execute - Begin");
	int * l_result = new int;
	*l_result = EncodeFile();
	Log::LogMessage( "EncoderThread :: Execute - End");
	return l_result;
}

//**********************************************************************************************************

int EncoderThread :: EncodeFile()
{
	if (m_inFileName.empty() || m_outFileName.empty())
	{
		Log::LogMessage( "ERROR : EncoderThread :: Encode - Void files names");
		return 1;
	}

	std :: ifstream l_inFile( m_inFileName.char_str(), std :: ios :: binary);
	if ( ! l_inFile)
	{
		return 2;
	}

	l_inFile.read( (char *) & startID, sizeof( startID));

	FormatChunk l_formatChunk;
	long l_formatChunkSize = sizeof( FormatChunk);

	wxString l_wav2mp3Error = wxT( "Erreur de conversion de WAV à MP3");

	l_inFile.read( (char *) & l_formatChunk, l_formatChunkSize);

	if (strncmp( l_formatChunk.chunkID, "fmt ", 4) != 0)
	{
		wxMessageBox( wxT( "Fichier WAV invalide"), l_wav2mp3Error, wxOK);
		return 3;
	}
	if (l_formatChunk.wFormatTag!=1)
	{
		wxMessageBox( wxT( "Impossible de compresser un WAV compressé"), l_wav2mp3Error, wxOK);
		return 4;
	}

	BE_CONFIG l_config;
	l_config.dwConfig = BE_CONFIG_LAME;
	l_config.format.LHV1.dwStructVersion = 1;
	l_config.format.LHV1.dwStructSize = sizeof( l_config);

	if (l_formatChunk.dwSamplesPerSec == 8000 || l_formatChunk.dwSamplesPerSec == 11025 ||
		l_formatChunk.dwSamplesPerSec == 12000 || l_formatChunk.dwSamplesPerSec == 16000 ||
		l_formatChunk.dwSamplesPerSec == 22050 || l_formatChunk.dwSamplesPerSec == 24000 ||
		l_formatChunk.dwSamplesPerSec == 32000 || l_formatChunk.dwSamplesPerSec == 44100 ||
		l_formatChunk.dwSamplesPerSec == 48000)
	{
		l_config.format.LHV1.dwSampleRate = l_formatChunk.dwSamplesPerSec;
		l_config.format.LHV1.dwReSampleRate = m_encodingOptions->m_sampleRate;
	}
	else
	{
		wxMessageBox( wxT( "Sample Rate non supporté"), l_wav2mp3Error, wxOK);
		return 5;
	}

	if (m_encodingOptions->m_vbr)
	{                       
		Log::LogMessage( "VBR - Bitrates : Min : %d - Max : %d", m_encodingOptions->m_vbrMinBitRate, m_encodingOptions->m_vbrMaxBitRate);
		l_config.format.LHV1.bEnableVBR = TRUE;
		l_config.format.LHV1.dwBitrate = m_encodingOptions->m_vbrMinBitRate;
		l_config.format.LHV1.dwMaxBitrate = m_encodingOptions->m_vbrMaxBitRate;
		l_config.format.LHV1.nVBRQuality = 8 - m_encodingOptions->m_vbrQuality;
		if (m_encodingOptions->m_vbrEnableXingTag)
		{
			l_config.format.LHV1.bWriteVBRHeader = FALSE;
		}
	}
	else
	{
		Log::LogMessage( "CBR - Bitrate : %d", m_encodingOptions->m_cbrBitRate);
		l_config.format.LHV1.bEnableVBR = FALSE;
		l_config.format.LHV1.dwBitrate = m_encodingOptions->m_cbrBitRate;
	}
	
	l_config.format.LHV1.nQuality = m_encodingOptions->m_encodingQuality;
	l_config.format.LHV1.nPreset = LQP_NORMAL_QUALITY;
	l_config.format.LHV1.dwMpegVersion = MPEG1;
	l_config.format.LHV1.dwPsyModel = 0;
	l_config.format.LHV1.dwEmphasis = 0;

	if (m_encodingOptions->m_stereoMode == Mono)
	{
		l_config.format.LHV1.nMode = BE_MP3_MODE_MONO;
	}
	else if (m_encodingOptions->m_stereoMode == StandardStereo)
	{
		l_config.format.LHV1.nMode = BE_MP3_MODE_STEREO;
	}
	else if (m_encodingOptions->m_stereoMode == DualChannel)
	{
		l_config.format.LHV1.nMode = BE_MP3_MODE_DUALCHANNEL;
	}
	else if (m_encodingOptions->m_stereoMode == JointStereo)
	{
		l_config.format.LHV1.nMode = BE_MP3_MODE_JSTEREO;
	}

	if (m_encodingOptions->m_strictISOComplience)
	{
		l_config.format.LHV1.bStrictIso = TRUE;
	}
	else
	{
		l_config.format.LHV1.bStrictIso = FALSE;
	}

	l_config.format.LHV1.bCopyright = FALSE;
	l_config.format.LHV1.bCRC = FALSE;
	l_config.format.LHV1.bOriginal = FALSE;
	l_config.format.LHV1.bPrivate = FALSE;
	l_config.format.LHV1.bNoRes = TRUE;

	if (l_formatChunkSize < 8 + l_formatChunk.chunkSize)
	{
		char c;
		for (int i = 0 ; i < 8 + l_formatChunk.chunkSize - l_formatChunkSize ; i++)
		{
			l_inFile.get( c);
		}
	}

	Chunk l_chunk;
	long l_chunkSize = sizeof( Chunk);
	l_inFile.read( (char*) & l_chunk, l_chunkSize);

	Log::LogMessage( "ChunkID : %s", l_chunk.chunkID);

	while (strncmp( l_chunk.chunkID, "data", 4) != 0)
	{
		char c;
		for (int i = 0 ; i < l_chunk.chunkSize ; i++)
		{
			l_inFile.get( c);
		}
		l_inFile.read((char*) & l_chunk, l_chunkSize);
	}

	unsigned long l_numberOfSamples;
	unsigned long l_outputBufferLength;
	HBE_STREAM l_hbeStream;
	if (beInitStream( & l_config, & l_numberOfSamples, & l_outputBufferLength,
					  & l_hbeStream) != BE_ERR_SUCCESSFUL)
	{
		wxMessageBox( wxT( "Erreur d'initialisation de Lame"), l_wav2mp3Error, wxOK);
		return 6;
	}
	std :: ofstream l_outFile( m_outFileName.char_str(), std :: ios :: binary);
	unsigned char * l_mp3Buffer = new unsigned char[ l_outputBufferLength];
	short * l_inputBuffer = new short[l_numberOfSamples];      //SHORT=short=16 bits

	int l_samplesPerformed = 0;
	unsigned long l_numberOfSamplesEncoded;
	while (l_samplesPerformed < l_chunk.chunkSize)
	{
		l_inFile.read( (char *) l_inputBuffer, l_numberOfSamples * 2);
		l_samplesPerformed += l_numberOfSamples * 2;
		g_formEncode->m_status->SetValue( 100 * ((l_samplesPerformed * 1.0) / l_chunk.chunkSize));
		if (beEncodeChunk( l_hbeStream, l_numberOfSamples, l_inputBuffer,
						   l_mp3Buffer, & l_numberOfSamplesEncoded) != BE_ERR_SUCCESSFUL)
		{
			wxMessageBox( wxT( "Problème de compression"), l_wav2mp3Error, wxOK);
			return 7;
		}
		l_outFile.write( (char *)l_mp3Buffer, l_numberOfSamplesEncoded);
	}
	beDeinitStream( l_hbeStream, l_mp3Buffer, & l_numberOfSamplesEncoded);
	beCloseStream( l_hbeStream);

	delete l_mp3Buffer;
	delete l_inputBuffer;

	g_formEncode->Hide();
	g_formEncode->m_panelStepOne->Show();
	g_formEncode->m_panelStepThree->Hide();

	Log::LogMessage( "EncoderThread :: Encode - End");

	return 0;
}

//**********************************************************************************************************
