//**********************************************************************************************************
#include "PrecompiledHeader.h"

#include "ImageButton.h"
#include <wx/dcclient.h>
//**********************************************************************************************************
using namespace JokersPlayer;
//**********************************************************************************************************
BEGIN_EVENT_TABLE( ImageButton, wxButton)
	EVT_LEFT_DOWN(		ImageButton::_onMouseLeftDown)
	EVT_LEFT_UP(		ImageButton::_onMouseLeftUp)
	EVT_LEAVE_WINDOW(	ImageButton::_onMouseLeave)
	EVT_ENTER_WINDOW(	ImageButton::_onMouseEnter)
	EVT_PAINT(			ImageButton::_onPaint)
END_EVENT_TABLE()
//**********************************************************************************************************

ImageButton :: ImageButton( wxWindow * p_parent, wxWindowID p_id, 
						    const wxString & p_caption, const wxPoint & p_position,
							const wxSize & p_size, int p_style)
	:	wxButton( p_parent, p_id, p_caption, p_position, p_size, wxNO_BORDER),
		m_mouseDown			( false),
		m_mouseOver			( false),
		m_down				( false),
		m_enabled			( true),
		m_caption			( p_caption),
		m_autoSize			( false),
		m_stretch			( false),
		m_center			( false),
		m_transparent		( false),
		m_border			( false),
		m_roundBorder		( false),
		m_font				( wxFont( 8, wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_NORMAL)),
		m_backgroundColour	( wxColour( 192, 192, 192))
{
	if ((p_style & jbSTRETCH) != 0)
	{
		m_stretch = true;
	}

	if ((p_style & jbCENTER) != 0)
	{
		m_center = true;
	}

	if ((p_style & jbTRANSPARENT) != 0)
	{
		m_transparent = true;
	}

	if ((p_style & jbBORDER) != 0)
	{
		m_border = true;
	}

	if ((p_style & jbROUNDBORDER) != 0)
	{
		m_roundBorder = true;
	}

	m_images.push_back( wxBitmap());
	m_images.push_back( wxBitmap());
	m_images.push_back( wxBitmap());
	m_images.push_back( wxBitmap());
	m_colours.push_back( wxColour( 192, 192, 192));
	m_colours.push_back( wxColour( 192, 192, 192));
	m_colours.push_back( wxColour( 192, 192, 192));
	m_colours.push_back( wxColour( 192, 192, 192));
	m_fontColours.push_back( wxColour( wxT( "black")));
	m_fontColours.push_back( wxColour( wxT( "black")));
	m_fontColours.push_back( wxColour( wxT( "black")));
	m_fontColours.push_back( wxColour( wxT( "black")));
}

//**********************************************************************************************************

void ImageButton :: SetImages( const wxBitmapArray & p_images)
{
	for (size_t i = 0 ; i < p_images.size() ; i++)
	{
		m_images[i] = p_images[i];
	}
}

//**********************************************************************************************************

void ImageButton :: SetColours( const wxColourArray & p_colours)
{
	for (size_t i = 0 ; i < p_colours.size() ; i++)
	{
		m_colours[i] = p_colours[i];
	}
}

//**********************************************************************************************************

void ImageButton :: SetFontColours( const wxColourArray & p_colours)
{
	for (size_t i = 0 ; i < p_colours.size() ; i++)
	{
		m_fontColours[i] = p_colours[i];
	}
}

//**********************************************************************************************************

void ImageButton :: _onMouseEnter( wxMouseEvent & p_event)
{
	m_mouseOver = true;
	Refresh();
	p_event.Skip();
}

//**********************************************************************************************************
	
void ImageButton :: _onMouseLeave( wxMouseEvent & p_event)
{
	m_mouseOver = false;
	m_mouseDown = false;
	m_down = false;
	Refresh();
	p_event.Skip();
}

//**********************************************************************************************************
	
void ImageButton :: _onMouseLeftDown( wxMouseEvent & p_event)
{
	m_mouseDown = true;
	Refresh();
	p_event.Skip();
}

//**********************************************************************************************************
	
void ImageButton :: _onMouseLeftUp( wxMouseEvent & p_event)
{
	m_mouseDown = false;
	m_down = false;
	Refresh();
	p_event.Skip();
}

//**********************************************************************************************************
	
void ImageButton :: _onPaint( wxPaintEvent & p_event)
{
	wxSize l_size = GetClientSize();
	int h = m_images[jiENABLE].GetHeight();
	int y = (l_size.y - h) / 2;
	int l = m_images[jiENABLE].GetWidth();
	int x = (l_size.x - l) / 2;

	if ( ! m_center)
	{
		x = 0;
		y = 0;
	}

	bool l_imaged = true;
	wxBitmap l_image;
	wxColour l_colour;
	wxColour l_fontColour;
	wxFont l_font;

	l_image = m_images[jiENABLE];
	l_colour = m_colours[jiENABLE];
	l_fontColour = m_fontColours[jiENABLE];

	if ( ! m_enabled)
	{
		if (m_images[jiDISABLE].IsOk())
		{
			l_image = m_images[jiDISABLE];
		}
		l_colour = m_colours[jiDISABLE];
		l_fontColour = m_fontColours[jiDISABLE];
	}
	else if (m_mouseDown || m_down)
	{
		if (m_images[jiDOWN].IsOk())
		{
			l_image = m_images[jiDOWN];
		}
		l_colour = m_colours[jiDOWN];
		l_fontColour = m_fontColours[jiDOWN];
	}
	else if (m_mouseOver)
	{
		if (m_images[jiMOUSEOVER].IsOk())
		{
			l_image = m_images[jiMOUSEOVER];
		}
		l_colour = m_colours[jiMOUSEOVER];
		l_fontColour = m_fontColours[jiMOUSEOVER];
	}
	else if ( ! m_images[jiENABLE].IsOk())
	{
		l_imaged = false;
	}

	wxPaintDC l_dc( this);
	l_dc.DestroyClippingRegion();
	wxRect l_rect( 0, 0, l_size.x, l_size.y);
	l_dc.SetClippingRegion( l_rect);
	wxBrush l_brush( l_dc.GetBrush());
	wxPen l_pen( l_dc.GetPen());

	if (m_border)
	{
		l_rect.x += 1;
		l_rect.y += 1;
		l_rect.height -= 2;
		l_rect.width -= 2;
		l_brush.SetStyle( wxSOLID);

		if (m_roundBorder)
		{
			l_brush.SetColour( m_backgroundColour);
			l_pen.SetColour( m_backgroundColour);
			l_dc.SetBrush( l_brush);
			l_dc.SetPen( l_pen);
			l_dc.DrawRectangle( 0, 0, l_size.x, l_size.y);

			l_brush.SetColour( l_colour);
			l_pen.SetColour( wxColour( wxT( "black")));
			float l_rayon = l_size.y / 4.0;
			l_dc.SetBrush( l_brush);
			l_dc.SetPen( l_pen);
			l_dc.DrawRoundedRectangle( 0, 0, l_size.x, l_size.y, l_rayon);
		}
		else
		{
			l_pen.SetColour( wxColour( wxT( "black")));
			l_brush.SetColour( l_colour);
			l_dc.SetBrush( l_brush);
			l_dc.SetPen( l_pen);
			l_dc.DrawRectangle( 0, 0, l_size.x, l_size.y);
		}
	}
	else
	{
		l_brush.SetColour( l_colour);
		l_pen.SetColour( l_colour);
		l_dc.SetBrush( l_brush);
		l_dc.SetPen( l_pen);
		l_dc.DrawRectangle( 0, 0, l_size.x, l_size.y);
	}

	if (l_imaged)
	{
		int h = l_image.GetHeight();
		int y = (l_size.y - h) / 2;
		int l = l_image.GetWidth();
		int x = (l_size.x - l) / 2;
		if (m_border)
		{                   
			h -= 2;
			y -= 1;
			l -= 2;
			x -= 1;
		}

		if (m_stretch)
		{
			l_image = wxBitmap( l_image.ConvertToImage().Scale( l, h, wxIMAGE_QUALITY_HIGH));
		}
		l_dc.DrawBitmap( l_image, x, y, m_transparent);
		l_brush.SetStyle( wxTRANSPARENT);
		l_dc.SetBrush( l_brush);
	}

	l_dc.SetFont( m_font);

	if (m_center)
	{
		wxSize l_textSize = l_dc.GetTextExtent( m_caption);
		l_size = GetClientSize();
		x = (l_size.x - l_textSize.x) / 2;
		y = (l_size.y - l_textSize.y) / 2;
	}

	l_dc.SetTextBackground( l_colour);
	l_dc.SetTextForeground( l_fontColour);
	l_dc.DrawText( m_caption, wxPoint( x, y));
}

//**********************************************************************************************************
