//**********************************************************************************************************
#ifndef ___ImageButton___
#define ___ImageButton___
//**********************************************************************************************************
#include <wx/button.h>
#include <wx/bitmap.h>
#include <wx/image.h>
#include <vector>
//**********************************************************************************************************
namespace JokersPlayer
{
	enum JokerButtonIndexes
	{
		jiENABLE,
		jiMOUSEOVER,
		jiDOWN,
		jiDISABLE,
	};

	const int jbCENTER		= 0x00000001;
	const int jbSTRETCH		= 0x00000010;
	const int jbTRANSPARENT	= 0x00000100;
	const int jbBORDER		= 0x00001000;
	const int jbROUNDBORDER	= 0x00010000;

	typedef std::vector <wxBitmap>	wxBitmapArray;
	typedef std::vector <wxColour>	wxColourArray;

	class ImageButton : public wxButton
	{
	private:
		bool m_mouseDown;
		bool m_mouseOver;
		bool m_down;
		bool m_enabled;
		wxString m_caption;
		bool m_autoSize;

		bool m_stretch;
		bool m_center;
		bool m_transparent;
		bool m_border;
		bool m_roundBorder;

		wxBitmapArray m_images;
		wxColourArray m_colours;
		wxFont m_font;
		wxColourArray m_fontColours;

		wxColour m_backgroundColour;

	public:
		ImageButton( wxWindow * p_parent, wxWindowID p_id, const wxString & p_caption,
					 const wxPoint & p_position, const wxSize & p_size, int p_style = 0);
		
		virtual bool Enable( bool p_value) { return (m_enabled = p_value); }
		virtual bool SetBackgroundColour( const wxColour & p_colour) { m_backgroundColour = p_colour;return true; }
		virtual const wxColour & GetBackgroundColour() { return m_backgroundColour; }
		virtual bool SetFont( const wxFont & p_font) { m_font = p_font;return true; }
		void SetImages( const wxBitmapArray & p_images);
		void SetColours( const wxColourArray & p_colours);
		void SetFontColours( const wxColourArray & p_colours);

	private:
		void _onMouseEnter		( wxMouseEvent & p_event);
		void _onMouseLeave		( wxMouseEvent & p_event);
		void _onMouseLeftDown	( wxMouseEvent & p_event);
		void _onMouseLeftUp		( wxMouseEvent & p_event);
		void _onPaint			( wxPaintEvent & p_event);

	public:
		inline void SetCaption( const wxString & p_caption) { m_caption = p_caption; }

		inline void SetAutoSize		( bool p_value) { m_autoSize = p_value; }

		inline void SetStretch		( bool p_value) { m_stretch = p_value; }
		inline void SetCenter		( bool p_value) { m_center = p_value; }
		inline void SetTransparent	( bool p_value) { m_transparent = p_value; }
		inline void SetBorder		( bool p_value) { m_border = p_value; }
		inline void SetRoundBorder	( bool p_value) { m_roundBorder = p_value; }

		inline void SetImageEnable			( const wxBitmap & p_image)		{ m_images[jiENABLE] = p_image; }
		inline void SetImageMouseOver		( const wxBitmap & p_image)		{ m_images[jiMOUSEOVER] = p_image; }
		inline void SetImageDown			( const wxBitmap & p_image)		{ m_images[jiDOWN] = p_image; }
		inline void SetImageDisable			( const wxBitmap & p_image)		{ m_images[jiDISABLE] = p_image; }
		inline void SetColourEnable			( const wxColour & p_colour)	{ m_colours[jiENABLE] = p_colour; }
		inline void SetColourMouseOver		( const wxColour & p_colour)	{ m_colours[jiMOUSEOVER] = p_colour; }
		inline void SetColourDown			( const wxColour & p_colour)	{ m_colours[jiDOWN] = p_colour; }
		inline void SetColourDisable		( const wxColour & p_colour)	{ m_colours[jiDISABLE] = p_colour; }
		inline void SetFontColourEnable		( const wxColour & p_colour)	{ m_fontColours[jiENABLE] = p_colour; }
		inline void SetFontColourMouseOver	( const wxColour & p_colour)	{ m_fontColours[jiMOUSEOVER] = p_colour; }
		inline void SetFontColourDown		( const wxColour & p_colour)	{ m_fontColours[jiDOWN] = p_colour; }
		inline void SetFontColourDisable	( const wxColour & p_colour)	{ m_fontColours[jiDISABLE] = p_colour; }

		inline const wxBitmap & GetImageEnable			() { return m_images[jiENABLE]; }
		inline const wxBitmap & GetImageMouseOver		() { return m_images[jiMOUSEOVER]; }
		inline const wxBitmap & GetImageDown			() { return m_images[jiDOWN]; }
		inline const wxBitmap & GetImageDisable			() { return m_images[jiDISABLE]; }
		inline const wxColour & GetColourEnable			() { return m_colours[jiENABLE]; }
		inline const wxColour & GetColourMouseOver		() { return m_colours[jiMOUSEOVER]; }
		inline const wxColour & GetColourDown			() { return m_colours[jiDOWN]; }
		inline const wxColour & GetColourDisable		() { return m_colours[jiDISABLE]; }
		inline const wxColour & GetFontColourEnable		() { return m_fontColours[jiENABLE]; }
		inline const wxColour & GetFontColourMouseOver	() { return m_fontColours[jiMOUSEOVER]; }
		inline const wxColour & GetFontColourDown		() { return m_fontColours[jiDOWN]; }
		inline const wxColour & GetFontColourDisable	() { return m_fontColours[jiDISABLE]; }
		inline const wxFont & GetFont					() { return m_font; }

		DECLARE_EVENT_TABLE()
	};
}
//**********************************************************************************************************
#endif
//**********************************************************************************************************
